@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 import contextlib
+from datetime import datetime
 from functools import wraps
 import io
 import json
@@ -23,12 +24,7 @@ from anyscale._private.anyscale_client.common import (
     RUNTIME_ENV_PACKAGE_FORMAT,
 )
 from anyscale._private.models.image_uri import ImageURI
-from anyscale._private.models.model_base import InternalListResponse, ListResponse
-from anyscale._private.utils.progress_util import (
-    FileDownloadProgress,
-    ProgressFileReader,
-)
-from anyscale.api_utils.common_utils import source_cloud_id_and_project_id
+from anyscale._private.utils.progress_util import FileDownloadProgress
 from anyscale.api_utils.logs_util import _download_log_from_s3_url_sync
 from anyscale.authenticate import AuthenticationBlock, get_auth_api_client
 from anyscale.cli_logger import BlockLogger
@@ -47,28 +43,23 @@ from anyscale.client.openapi_client.models import (
     CloudDataBucketPresignedUrlScheme,
     CloudNameOptions,
     ClusteroperationResponse,
+    CollaboratorType,
     ComputeTemplate,
     ComputeTemplateConfig,
     ComputeTemplateQuery,
     CreateCloudCollaborator,
     CreateComputeTemplate,
-    CreateDataset,
     CreateExperimentalWorkspace,
     CreateInternalProductionJob,
     CreateOrganizationInvitation,
     CreateResourceQuota,
     CreateUserProjectCollaborator,
-    Dataset as InternalDataset,
-    DatasetUpload,
     DecoratedComputeTemplate,
     DecoratedjobqueueListResponse,
     DecoratedlistserviceapimodelListResponse,
     DecoratedProductionServiceV2APIModel,
     DecoratedSession,
-    DeletedPlatformFineTunedModel,
     ExperimentalWorkspace,
-    FineTunedModel,
-    FinetunedmodelListResponse,
     GetOrCreateBuildFromImageUriRequest,
     InternalProductionJob,
     JobQueueSortDirective,
@@ -76,6 +67,9 @@ from anyscale.client.openapi_client.models import (
     ListResourceQuotasQuery,
     OrganizationCollaborator,
     OrganizationInvitation,
+    Project,
+    ProjectBase,
+    ProjectListResponse,
     ResourceQuota,
     ResourceQuotaStatus,
     ServerSessionToken,
@@ -85,6 +79,7 @@ from anyscale.client.openapi_client.models import (
     StopSessionOptions,
     SystemWorkloadName,
     WorkspaceDataplaneProxiedArtifacts,
+    WriteProject,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
 from anyscale.client.openapi_client.models.decorated_job_queue import DecoratedJobQueue
@@ -113,7 +108,7 @@ from anyscale.sdk.anyscale_client.models import (
     CreateClusterEnvironmentBuild,
     Job as APIJobRun,
     ProductionServiceV2VersionModel,
-    Project,
+    Project as ProjectExternal,
     RollbackServiceModel,
     TextQuery,
 )
@@ -167,7 +162,7 @@ def handle_api_exceptions(func):
                     body_dict = json.loads(e.body)
                     msg = body_dict["error"]["detail"]
                     raise ValueError(msg) from None
-                except KeyError:
+                except (KeyError, TypeError):
                     # ApiException doesn't conform to expected format, raise original error
                     raise e from None
             raise e from None
@@ -493,7 +488,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         if self._default_project_id_from_cloud_id.get(parent_cloud_id) is None:
             # Cloud isolation organizations follow the permissions model in https://docs.anyscale.com/organization-and-user-account/access-controls
-            default_project: Project = self._external_api_client.get_default_project(
+            default_project: ProjectExternal = self._external_api_client.get_default_project(
                 parent_cloud_id=parent_cloud_id
             ).result
             self._default_project_id_from_cloud_id[parent_cloud_id] = default_project.id
@@ -1059,11 +1054,53 @@ class AnyscaleClient(AnyscaleClientInterface):
         )
 
     @handle_api_exceptions
-    def get_project(self, project_id: str) -> Optional[Project]:
+    def get_project(self, project_id: str) -> Project:
         return self._internal_api_client.get_project_api_v2_projects_project_id_get(
             project_id
         ).result
 
+    @handle_api_exceptions
+    def list_projects(
+        self,
+        *,
+        name_contains: Optional[str] = None,
+        creator_id: Optional[str] = None,
+        parent_cloud_id: Optional[str] = None,
+        include_defaults: bool = True,
+        sort_field: Optional[str] = None,
+        sort_order: Optional[str] = None,
+        paging_token: Optional[str] = None,
+        count: Optional[int] = None,
+    ) -> ProjectListResponse:
+        return self._internal_api_client.list_projects_api_v2_projects_get(
+            name_contains=name_contains,
+            creator_id=creator_id,
+            parent_cloud_id=parent_cloud_id,
+            include_defaults=include_defaults,
+            sort_field=sort_field,
+            sort_order=sort_order,
+            paging_token=paging_token,
+            count=count or self.LIST_ENDPOINT_COUNT,
+        )
+
+    @handle_api_exceptions
+    def create_project(self, project: WriteProject) -> ProjectBase:
+        return self._internal_api_client.create_project_api_v2_projects_post(
+            project
+        ).result
+
+    @handle_api_exceptions
+    def delete_project(self, project_id: str) -> None:
+        self._internal_api_client.delete_project_api_v2_projects_project_id_delete(
+            project_id
+        )
+
+    @handle_api_exceptions
+    def get_default_project(self, parent_cloud_id: str) -> Project:
+        return self._internal_api_client.get_default_project_api_v2_projects_default_project_get(
+            parent_cloud_id=parent_cloud_id,
+        ).result
+
     @handle_api_exceptions
     def add_project_collaborators(
         self, project_id: str, collaborators: List[CreateUserProjectCollaborator]
@@ -1252,6 +1289,64 @@ class AnyscaleClient(AnyscaleClientInterface):
             job_id
         )
 
+    def _upload_local_runtime_env(
+        self,
+        cloud_id: str,
+        cloud_resource_id: Optional[str],
+        zip_file_bytes: bytes,
+        content_hash: str,
+        overwrite_existing_file: bool,
+    ) -> CloudDataBucketPresignedUrlResponse:
+        file_name = RUNTIME_ENV_PACKAGE_FORMAT.format(content_hash=content_hash)
+        request = CloudDataBucketPresignedUrlRequest(
+            file_type=CloudDataBucketFileType.RUNTIME_ENV_PACKAGES,
+            file_name=file_name,
+            access_mode=CloudDataBucketAccessMode.WRITE,
+            cloud_resource_id=cloud_resource_id,
+        )
+        info: CloudDataBucketPresignedUrlResponse = self._internal_api_client.generate_cloud_data_bucket_presigned_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_url_post(
+            cloud_id, request
+        ).result
+
+        # Skip the upload entirely if the file already exists.
+        if info.file_exists and not overwrite_existing_file:
+            internal_logger.debug(
+                f"Skipping file upload for '{file_name}' because it already exists in cloud storage."
+            )
+            return info
+
+        if info.url_scheme == CloudDataBucketPresignedUrlScheme.SMART_OPEN:
+            # If the presigned URL scheme is SMART_OPEN, upload to cloud storage using the provided bucket name, path, & environment, and the smart_open library.
+            bucket_name = info.bucket_name
+            bucket_path = info.bucket_path
+
+            env_vars: Dict[str, str] = {
+                "AWS_ENDPOINT_URL": info.url,
+            }
+            with set_env(**env_vars), smart_open.open(
+                f"{bucket_name}/{bucket_path}", "wb",
+            ) as fout:
+                fout.write(zip_file_bytes)
+
+        else:
+            # Default to HTTP PUT.
+            internal_logger.debug(f"Uploading file '{file_name}' to cloud storage.")
+            headers = None
+            if info.file_uri.startswith("azure") or info.file_uri.startswith("abfss"):
+                headers = {
+                    "x-ms-blob-type": "BlockBlob",
+                    "x-ms-version": "2025-07-05",
+                    "x-ms-date": datetime.utcnow().strftime(
+                        "%a, %d %b %Y %H:%M:%S GMT"
+                    ),
+                    "x-ms-blob-content-type": "application/zip",
+                }
+            requests.put(
+                info.url, data=zip_file_bytes, headers=headers
+            ).raise_for_status()
+
+        return info
+
     @handle_api_exceptions
     def upload_local_dir_to_cloud_storage(
         self,
@@ -1260,58 +1355,91 @@ class AnyscaleClient(AnyscaleClientInterface):
         cloud_id: str,
         excludes: Optional[List[str]] = None,
         overwrite_existing_file: bool = OVERWRITE_EXISTING_CLOUD_STORAGE_FILES,
+        cloud_resource_name: Optional[str] = None,
     ) -> str:
         if not pathlib.Path(local_dir).is_dir():
             raise RuntimeError(f"Path '{local_dir}' is not a valid directory.")
 
+        cloud_resource_id = None
+        if cloud_resource_name is not None:
+            cloud_resources = self._internal_api_client.get_cloud_resources_api_v2_clouds_cloud_id_resources_get(
+                cloud_id=cloud_id,
+            ).results
+            cloud_resource_id = next(
+                (
+                    cloud_resource.cloud_resource_id
+                    for cloud_resource in cloud_resources
+                    if cloud_resource.name == cloud_resource_name
+                ),
+                None,
+            )
+            if cloud_resource_id is None:
+                raise ValueError(
+                    f"Cloud resource '{cloud_resource_name}' not found in cloud '{cloud_id}'"
+                )
+
         with zip_local_dir(local_dir, excludes=excludes) as (
             _,
             zip_file_bytes,
             content_hash,
         ):
-            file_name = RUNTIME_ENV_PACKAGE_FORMAT.format(content_hash=content_hash)
-            request = CloudDataBucketPresignedUrlRequest(
-                file_type=CloudDataBucketFileType.RUNTIME_ENV_PACKAGES,
-                file_name=file_name,
-                access_mode=CloudDataBucketAccessMode.WRITE,
+            info = self._upload_local_runtime_env(
+                cloud_id=cloud_id,
+                cloud_resource_id=cloud_resource_id,
+                zip_file_bytes=zip_file_bytes,
+                content_hash=content_hash,
+                overwrite_existing_file=overwrite_existing_file,
             )
-            info: CloudDataBucketPresignedUrlResponse = self._internal_api_client.generate_cloud_data_bucket_presigned_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_url_post(
-                cloud_id, request
-            ).result
+            return info.file_uri
 
-            # Skip the upload entirely if the file already exists.
-            if info.file_exists and not overwrite_existing_file:
-                internal_logger.debug(
-                    f"Skipping file upload for '{file_name}' because it already exists in cloud storage."
+    def upload_local_dir_to_cloud_storage_multi_cloud_resource(
+        self,
+        local_dir: str,
+        *,
+        cloud_id: str,
+        cloud_resource_names: List[Optional[str]],
+        excludes: Optional[List[str]] = None,
+        overwrite_existing_file: bool = False,
+    ) -> str:
+        if not pathlib.Path(local_dir).is_dir():
+            raise RuntimeError(f"Path '{local_dir}' is not a valid directory.")
+
+        all_cloud_resources = self._internal_api_client.get_cloud_resources_api_v2_clouds_cloud_id_resources_get(
+            cloud_id=cloud_id,
+        ).results
+        cloud_resource_names_to_ids = {
+            cloud_resource.name: cloud_resource.cloud_resource_id
+            for cloud_resource in all_cloud_resources
+        }
+
+        bucket_paths = set()
+
+        with zip_local_dir(local_dir, excludes=excludes) as (
+            _,
+            zip_file_bytes,
+            content_hash,
+        ):
+            for cloud_resource_name in cloud_resource_names:
+                if cloud_resource_name is not None:
+                    if cloud_resource_name not in cloud_resource_names_to_ids:
+                        raise ValueError(
+                            f"Cloud resource '{cloud_resource_name}' not found in cloud '{cloud_id}'"
+                        )
+                    cloud_resource_id = cloud_resource_names_to_ids[cloud_resource_name]
+                else:
+                    cloud_resource_id = None
+
+                info = self._upload_local_runtime_env(
+                    cloud_id=cloud_id,
+                    cloud_resource_id=cloud_resource_id,
+                    zip_file_bytes=zip_file_bytes,
+                    content_hash=content_hash,
+                    overwrite_existing_file=overwrite_existing_file,
                 )
-                return info.file_uri
+                bucket_paths.add(info.bucket_path)
 
-            if info.url_scheme == CloudDataBucketPresignedUrlScheme.SMART_OPEN:
-                # If the presigned URL scheme is SMART_OPEN, upload to cloud storage using the provided bucket name, path, & environment, and the smart_open library.
-                bucket_name = info.bucket_name
-                bucket_path = info.bucket_path
-
-                env_vars: Dict[str, str] = {
-                    "AWS_ENDPOINT_URL": info.url,
-                }
-                with set_env(**env_vars), smart_open.open(
-                    f"{bucket_name}/{bucket_path}", "wb",
-                ) as fout:
-                    fout.write(zip_file_bytes)
-
-            else:
-                # Default to HTTP PUT.
-                internal_logger.debug(f"Uploading file '{file_name}' to cloud storage.")
-                headers = (
-                    {"x-ms-blob-type": "BlockBlob"}
-                    if info.file_uri.startswith("azure")
-                    else None
-                )
-                requests.put(
-                    info.url, data=zip_file_bytes, headers=headers
-                ).raise_for_status()
-
-        return info.file_uri
+            assert len(bucket_paths) == 1
+            return bucket_paths.pop()
 
     def _fetch_log_chunks(self, job_run_id: str) -> Tuple[List[str], Any]:
         all_log_chunk_urls = []
@@ -1563,160 +1691,6 @@ class AnyscaleClient(AnyscaleClientInterface):
             id
         )
 
-    @handle_api_exceptions
-    def get_dataset(self, name: str, version: Optional[int], project: Optional[str]):
-        project_id = self._source_project_id(project)
-        internal_dataset = self._internal_api_client.find_dataset_api_v2_datasets_find_get(
-            name=name, version=version, project_id=project_id
-        ).result
-        from anyscale.llm.dataset._private.models import Dataset
-
-        dataset = Dataset.parse_from_internal_model(internal_dataset)
-        return dataset
-
-    def upload_dataset(
-        self,
-        dataset_file: str,
-        name: Optional[str],
-        description: Optional[str],
-        cloud: Optional[str],
-        project: Optional[str],
-    ):
-        # Resolve `~/.../file` to `/home/user/.../file`
-        dataset_file = os.path.expanduser(dataset_file)
-
-        if not os.path.isfile(dataset_file):
-            raise ValueError(f"Path '{dataset_file}' is not a valid file.")
-        dataset_file_size = os.path.getsize(dataset_file)
-        if dataset_file_size > 5 * Bytes.GB:
-            raise ValueError(
-                f"File '{dataset_file}' is too large to upload. The maximum size is 5 GB."
-            )
-        project_id = self._get_project_id_by_name(name=project) if project else None
-        cloud_id = self.get_cloud_id(cloud_name=cloud) if cloud else None
-
-        with FileDownloadProgress() as progress:
-            task_id = progress.add_task(
-                description=f"Creating an upload request for '{dataset_file}'",
-                total=dataset_file_size,
-            )
-            _, project_id = source_cloud_id_and_project_id(
-                internal_api=self._internal_api_client,
-                external_api=self._external_api_client,
-                cloud_id=cloud_id,
-                project_id=project_id,
-            )
-            dataset_upload: DatasetUpload = self._internal_api_client.create_dataset_upload_api_v2_datasets_upload_post(
-                create_dataset=CreateDataset(
-                    filename=os.path.basename(dataset_file),
-                    description=description,
-                    name=name,
-                    project_id=project_id,
-                )
-            ).result
-
-            progress.update(task_id, description=f"Uploading '{dataset_file}'")
-
-            with open(dataset_file, "rb") as file_reader:
-                progress_reader = ProgressFileReader(file_reader, progress, task_id)
-                response = requests.put(
-                    dataset_upload.upload_url, data=progress_reader,
-                )
-                response.raise_for_status()
-
-            progress.update(task_id, completed=os.path.getsize(dataset_file))
-            progress.console.print(
-                "Upload complete!", style=Style(bold=True, color="green")
-            )
-        internal_dataset = dataset_upload.dataset
-        from anyscale.llm.dataset._private.models import Dataset
-
-        dataset = Dataset.parse_from_internal_model(internal_dataset)
-        return dataset
-
-    @handle_api_exceptions
-    def download_dataset(
-        self, name: str, version: Optional[int], project: Optional[str]
-    ) -> bytes:
-        project_id = self._source_project_id(project)
-        with FileDownloadProgress() as progress:
-            task_id = progress.add_task(
-                description=f"Getting download info for '{name}'",
-            )
-            download_url: str = self._internal_api_client.get_dataset_download_url_api_v2_datasets_download_get(
-                name, version=version, project_id=project_id,
-            )
-            progress.update(task_id, description=f"Downloading '{name}'")
-            response = requests.get(download_url, stream=True)
-            total_size = int(response.headers.get("content-length", 0))
-            progress.update(task_id, total=total_size)
-
-            # For CLI, consider writing to disk instead of loading the entire file into memory.
-            dataset_bytes = b""
-            for data in response.iter_content(Bytes.MB):
-                dataset_bytes += data
-                progress.update(task_id, advance=len(data))
-
-            progress.update(task_id, completed=total_size)
-            progress.console.print(
-                "Download complete!", style=Style(bold=True, color="green")
-            )
-
-        return dataset_bytes
-
-    @handle_api_exceptions
-    def list_datasets(
-        self,
-        limit: Optional[int] = None,
-        after: Optional[str] = None,  # Unique ID to start listing after
-        name_contains: Optional[str] = None,
-        cloud: Optional[str] = None,
-        project: Optional[str] = None,
-    ):
-        project_id = self._source_project_id(project)
-        cloud_id = self.get_cloud_id(cloud_name=cloud) if cloud else None
-
-        def get_next_page(
-            after_id: Optional[str],
-        ) -> InternalListResponse[InternalDataset]:
-            internal_datasets: InternalListResponse = self._internal_api_client.list_datasets_api_v2_datasets_get(
-                project_id=project_id,
-                cloud_id=cloud_id,
-                name_contains=name_contains,
-                after=after_id,
-            )
-            return internal_datasets
-
-        from anyscale.llm.dataset._private.models import Dataset
-
-        list_response = ListResponse(
-            after=after, limit=limit, get_next_page=get_next_page, cls=Dataset,
-        )
-        return list_response
-
-    def _source_project_id(self, project_name: Optional[str]) -> Optional[str]:
-        """Sources a optional project ID from an optionally-provided project name."""
-        if project_name:
-            project_id = self._get_project_id_by_name(name=project_name)
-        else:
-            project_id = None
-        return project_id
-
-    @handle_api_exceptions
-    def get_finetuned_model(
-        self, model_id: Optional[str], job_id: Optional[str]
-    ) -> FineTunedModel:
-        if model_id:
-            return self._internal_api_client.get_model_api_v2_llm_models_model_id_get(
-                model_id
-            ).result
-        elif job_id:
-            return self._internal_api_client.get_model_by_job_id_api_v2_llm_models_get_by_job_id_job_id_get(
-                job_id
-            ).result
-        else:
-            raise ValueError("Atleast one of `model_id` or `job_id` must be provided")
-
     @handle_api_exceptions
     def create_workspace(self, model: CreateExperimentalWorkspace) -> str:
         return self._internal_api_client.create_workspace_api_v2_experimental_workspaces_post(
@@ -1897,48 +1871,6 @@ class AnyscaleClient(AnyscaleClientInterface):
         else:
             return project.name
 
-    @handle_api_exceptions
-    def delete_finetuned_model(self, model_id: str) -> DeletedPlatformFineTunedModel:
-        deleted_model = self._internal_api_client.delete_model_api_v2_llm_models_model_id_delete(
-            model_id
-        ).result
-        return deleted_model
-
-    @handle_api_exceptions
-    def list_finetuned_models(
-        self, cloud_id: Optional[str], project_id: Optional[str], max_items: int,
-    ) -> List[FineTunedModel]:
-        if self.inside_workspace():
-            # Resolve `cloud_id` and `project_id`. If not provided and if this is being run in a workspace,
-            # we use the `cloud_id` and `project_id` of the workspace
-            cloud_id, project_id = source_cloud_id_and_project_id(
-                internal_api=self._internal_api_client,
-                external_api=self._external_api_client,
-                cloud_id=cloud_id,
-                project_id=project_id,
-            )
-
-        paging_token = None
-        results = []
-        while True:
-            count = min(self.LIST_ENDPOINT_COUNT, max_items)
-            resp: FinetunedmodelListResponse = self._internal_api_client.list_models_api_v2_llm_models_get(
-                cloud_id=cloud_id,
-                project_id=project_id,
-                paging_token=paging_token,
-                count=count,
-            )
-            models = resp.results
-            results.extend(models)
-            if not len(models) or not resp.metadata.next_paging_token:
-                break
-
-            if max_items and len(results) >= max_items:
-                break
-            paging_token = resp.metadata.next_paging_token
-
-        return results[:max_items] if max_items else results
-
     @handle_api_exceptions
     def download_aggregated_instance_usage_csv(
         self,
@@ -2078,10 +2010,11 @@ class AnyscaleClient(AnyscaleClientInterface):
         self,
         email: Optional[str] = None,
         name: Optional[str] = None,
-        is_service_account: Optional[bool] = None,
+        collaborator_type: Optional[CollaboratorType] = None,
+        is_service_account: Optional[bool] = None,  # noqa: ARG002
     ) -> List[OrganizationCollaborator]:
         results = self._internal_api_client.list_organization_collaborators_api_v2_organization_collaborators_get(
-            email=email, name=name, is_service_account=is_service_account
+            email=email, name=name, collaborator_type=collaborator_type
         ).results
 
         return results
