@@ -9,6 +9,7 @@ from anyscale.client.openapi_client.models import (
     AnyscaleServiceAccount,
     Cloud,
     ClusteroperationResponse,
+    CollaboratorType,
     ComputeTemplateConfig,
     CreateCloudCollaborator,
     CreateExperimentalWorkspace,
@@ -19,17 +20,18 @@ from anyscale.client.openapi_client.models import (
     DecoratedjobqueueListResponse,
     DecoratedlistserviceapimodelListResponse,
     DecoratedProductionServiceV2APIModel,
-    DeletedPlatformFineTunedModel,
-    FineTunedModel,
     InternalProductionJob,
     JobQueueSortDirective,
     OrganizationCollaborator,
     OrganizationInvitation,
     Project,
+    ProjectBase,
+    ProjectListResponse,
     ResourceQuota,
     ServerSessionToken,
     SessionState,
     WorkspaceDataplaneProxiedArtifacts,
+    WriteProject,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
 from anyscale.client.openapi_client.models.decorated_job_queue import DecoratedJobQueue
@@ -55,7 +57,7 @@ from anyscale.utils.workspace_notification import WorkspaceNotification
 # Maybe just make it part of the release process to update it, or fetch the
 # default builds and get the latest one. The best thing to do is probably
 # to populate this in the backend.
-DEFAULT_RAY_VERSION = "2.47.1"  # RAY_RELEASE_UPDATE: update to latest version.
+DEFAULT_RAY_VERSION = "2.49.1"  # RAY_RELEASE_UPDATE: update to latest version.
 DEFAULT_PYTHON_VERSION = "py311"
 RUNTIME_ENV_PACKAGE_FORMAT = "pkg_{content_hash}.zip"
 
@@ -356,13 +358,44 @@ class AnyscaleClientInterface(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def get_project(self, project_id: str) -> Optional[Project]:
+    def get_project(self, project_id: str) -> Project:
         """Get a project by id.
 
         Returns None if not found.
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def list_projects(
+        self,
+        *,
+        name_contains: Optional[str] = None,
+        creator_id: Optional[str] = None,
+        parent_cloud_id: Optional[str] = None,
+        include_defaults: bool = True,
+        sort_field: Optional[str] = None,
+        sort_order: Optional[str] = None,
+        paging_token: Optional[str] = None,
+        count: Optional[int] = None,
+    ) -> ProjectListResponse:
+        """List projects."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def create_project(self, project: WriteProject) -> ProjectBase:
+        """Create a project."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def delete_project(self, project_id: str) -> None:
+        """Delete a project."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def get_default_project(self, parent_cloud_id: str) -> Project:
+        """Get the default project for the provided cloud ID."""
+        raise NotImplementedError
+
     @abstractmethod
     def add_project_collaborators(
         self, project_id: str, collaborators: List[CreateUserProjectCollaborator]
@@ -487,6 +520,7 @@ class AnyscaleClientInterface(ABC):
         cloud_id: str,
         excludes: Optional[List[str]] = None,
         overwrite_existing_file: bool = False,
+        cloud_resource_name: Optional[str] = None,
     ) -> str:
         """Upload the provided directory to cloud storage and return a URI for it.
 
@@ -500,6 +534,30 @@ class AnyscaleClientInterface(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def upload_local_dir_to_cloud_storage_multi_cloud_resource(
+        self,
+        local_dir: str,
+        *,
+        cloud_id: str,
+        cloud_resource_names: List[Optional[str]],
+        excludes: Optional[List[str]] = None,
+        overwrite_existing_file: bool = False,
+    ) -> str:
+        """Upload the provided directory to the object storage for each of the provided
+        cloud resources and return the bucket path of the uploaded file.
+
+        The directory will be zipped and the resulting bucket path will later be converted
+        to a URI that can be used in a Ray runtime_env.
+
+        The upload is preformed using a pre-signed URL fetched from Anyscale, so no
+        local cloud provider authentication is required.
+
+        The path is content-addressable (containing a hash of the directory contents), so by
+        default if the target file path already exists it will not be overwritten.
+        """
+        raise NotImplementedError
+
     @abstractmethod
     def logs_for_job_run(
         self,
@@ -574,41 +632,6 @@ class AnyscaleClientInterface(ABC):
         """
         raise NotImplementedError
 
-    @abstractmethod
-    def get_dataset(self, name: str, version: Optional[int], project: Optional[str]):
-        """See docstring for `anyscale.llm.dataset.get()`."""
-        raise NotImplementedError
-
-    @abstractmethod
-    def upload_dataset(
-        self,
-        dataset_file: str,
-        name: Optional[str],
-        description: Optional[str],
-        cloud: Optional[str],
-        project: Optional[str],
-    ):
-        """See docstring for `anyscale.llm.dataset.upload()`."""
-        raise NotImplementedError
-
-    @abstractmethod
-    def download_dataset(
-        self, name: str, version: Optional[int], project: Optional[str]
-    ) -> bytes:
-        """See docstring for `anyscale.llm.dataset.download()`."""
-
-    @abstractmethod
-    def list_datasets(
-        self,
-        limit: Optional[int] = None,
-        after: Optional[str] = None,  # Unique ID to start listing after
-        name_contains: Optional[str] = None,
-        cloud: Optional[str] = None,
-        project: Optional[str] = None,
-    ):
-        """See docstring for `anyscale.llm.dataset.list()`."""
-        raise NotImplementedError
-
     @abstractmethod
     def create_workspace(self, model: CreateExperimentalWorkspace) -> str:
         """Creates a workspace
@@ -656,13 +679,6 @@ class AnyscaleClientInterface(ABC):
         """Updates the dynamic dependencies of a workspace"""
         raise NotImplementedError
 
-    @abstractmethod
-    def get_finetuned_model(
-        self, model_id: Optional[str], job_id: Optional[str]
-    ) -> FineTunedModel:  # noqa: A002
-        """Returns LLM model information for the given model ID"""
-        raise NotImplementedError
-
     @abstractmethod
     def get_workspace_cluster(
         self, workspace_id: Optional[str]
@@ -692,17 +708,6 @@ class AnyscaleClientInterface(ABC):
         """Get the default directory name for a workspace."""
         raise NotImplementedError
 
-    @abstractmethod
-    def delete_finetuned_model(self, model_id: str) -> DeletedPlatformFineTunedModel:
-        """Deletes a finetuned model from the model registry given the model ID"""
-        raise NotImplementedError
-
-    @abstractmethod
-    def list_finetuned_models(
-        self, cloud_id: Optional[str], project_id: Optional[str], max_items: int,
-    ) -> List[FineTunedModel]:
-        raise NotImplementedError
-
     @abstractmethod
     def update_workspace(
         self,
@@ -770,6 +775,7 @@ class AnyscaleClientInterface(ABC):
         self,
         email: Optional[str] = None,
         name: Optional[str] = None,
+        collaborator_type: Optional[CollaboratorType] = None,
         is_service_account: Optional[bool] = None,
     ) -> List[OrganizationCollaborator]:
         """Get organization collaborators."""
