@@ -11,11 +11,19 @@ from anyscale import scripts
 from anyscale._private.docgen.generator import MarkdownGenerator, Module
 from anyscale.aggregated_instance_usage.models import DownloadCSVFilters
 from anyscale.cloud.models import (
+    AWSConfig,
     Cloud,
     CloudPermissionLevel,
     CloudProvider,
+    CloudResource,
     ComputeStack,
     CreateCloudCollaborator,
+    FileStorage,
+    GCPConfig,
+    KubernetesConfig,
+    NetworkingMode,
+    NFSMountTarget,
+    ObjectStorage,
 )
 from anyscale.commands import (
     aggregated_instance_usage_commands,
@@ -39,13 +47,13 @@ from anyscale.commands import (
     workspace_commands,
     workspace_commands_v2,
 )
-from anyscale.commands.llm import dataset_commands, models_commands
 from anyscale.compute_config.models import (
-    CloudDeployment,
+    CloudDeployment as CloudDeploymentSelector,
     ComputeConfig,
     ComputeConfigVersion,
     HeadNodeConfig,
     MarketType,
+    MultiResourceComputeConfig,
     WorkerNodeGroupConfig,
 )
 from anyscale.image.models import ImageBuild, ImageBuildStatus
@@ -60,14 +68,14 @@ from anyscale.job.models import (
     JobState,
     JobStatus,
 )
-from anyscale.llm.dataset._private.models import Dataset
-from anyscale.llm.model.models import (
-    DeletedFineTunedModel,
-    FineTunedModel,
-    FineTuningType,
-)
 from anyscale.organization_invitation.models import OrganizationInvitation
-from anyscale.project.models import CreateProjectCollaborator, ProjectPermissionLevel
+from anyscale.project.models import (
+    CreateProjectCollaborator,
+    Project,
+    ProjectPermissionLevel,
+    ProjectSortField,
+    ProjectSortOrder,
+)
 from anyscale.resource_quota.models import CreateResourceQuota, Quota, ResourceQuota
 from anyscale.schedule.models import ScheduleConfig, ScheduleState, ScheduleStatus
 from anyscale.service.models import (
@@ -108,25 +116,33 @@ ALL_MODULES = [
         title="Project",
         filename="project-api.md",
         cli_prefix="anyscale project",
-        cli_commands=[project_commands.add_collaborators,],
-        sdk_prefix="anyscale.project",
-        sdk_commands=[anyscale.project.add_collaborators,],
-        models=[ProjectPermissionLevel, CreateProjectCollaborator],
-        legacy_cli_commands=[project_commands.create, project_commands.list,],
-        legacy_sdk_commands={
-            "create_project": None,
-            "delete_project": None,
-            "get_default_project": None,
-            "get_project": None,
-            "search_projects": None,
-        },
-        legacy_sdk_models=[
-            "CreateProject",
-            "Project",
-            "ProjectListResponse",
-            "ProjectResponse",
-            "ProjectsQuery",
+        cli_commands=[
+            project_commands.get,
+            project_commands.list,
+            project_commands.create,
+            project_commands.delete,
+            project_commands.get_default,
+            project_commands.add_collaborators,
         ],
+        sdk_prefix="anyscale.project",
+        sdk_commands=[
+            anyscale.project.get,
+            anyscale.project.list,
+            anyscale.project.create,
+            anyscale.project.delete,
+            anyscale.project.get_default,
+            anyscale.project.add_collaborators,
+        ],
+        models=[
+            Project,
+            ProjectSortField,
+            ProjectSortOrder,
+            CreateProjectCollaborator,
+            ProjectPermissionLevel,
+        ],
+        legacy_cli_commands=[],
+        legacy_sdk_commands={},
+        legacy_sdk_models=[],
     ),
     Module(
         title="Job",
@@ -314,10 +330,11 @@ ALL_MODULES = [
         ],
         models=[
             ComputeConfig,
+            MultiResourceComputeConfig,
             HeadNodeConfig,
             WorkerNodeGroupConfig,
             MarketType,
-            CloudDeployment,
+            CloudDeploymentSelector,
             ComputeConfigVersion,
         ],
         legacy_sdk_commands={
@@ -431,6 +448,9 @@ ALL_MODULES = [
             cloud_commands.cloud_delete,
             cloud_commands.cloud_verify,
             cloud_commands.list_cloud,
+            cloud_commands.cloud_resource_create,
+            cloud_commands.cloud_resource_delete,
+            cloud_commands.cloud_config_get,
             cloud_commands.cloud_config_update,
             cloud_commands.cloud_set_default,
             cloud_commands.add_collaborators,
@@ -446,13 +466,26 @@ ALL_MODULES = [
             anyscale.cloud.terminate_system_cluster,
         ],
         models=[
+            Cloud,
             CloudPermissionLevel,
             CreateCloudCollaborator,
-            Cloud,
+            CloudResource,
             ComputeStack,
             CloudProvider,
+            NetworkingMode,
+            ObjectStorage,
+            FileStorage,
+            NFSMountTarget,
+            AWSConfig,
+            GCPConfig,
+            KubernetesConfig,
         ],
-        cli_command_group_prefix={cloud_commands.cloud_config_update: "config"},
+        cli_command_group_prefix={
+            cloud_commands.cloud_resource_create: "resource",
+            cloud_commands.cloud_resource_delete: "resource",
+            cloud_commands.cloud_config_get: "config",
+            cloud_commands.cloud_config_update: "config",
+        },
         legacy_sdk_commands={
             # limited support, no replacement yet
             "get_cloud": None,
@@ -579,40 +612,6 @@ ALL_MODULES = [
             "UpdateCluster",
         ],
     ),
-    Module(
-        title="LLM Model",
-        filename="llm_models.md",
-        cli_prefix="anyscale llm model",
-        cli_commands=[
-            models_commands.get_model,
-            models_commands.list_models,
-            models_commands.delete_model,
-        ],
-        sdk_prefix="anyscale.llm.model",
-        sdk_commands=[
-            anyscale.llm.model.get,
-            anyscale.llm.model.list,
-            anyscale.llm.model.delete,
-        ],
-        models=[FineTunedModel, FineTuningType, DeletedFineTunedModel],
-    ),
-    Module(
-        title="LLM Dataset",
-        filename="llm_dataset.md",
-        cli_prefix="anyscale llm dataset",
-        cli_commands=[
-            dataset_commands.get_dataset,
-            dataset_commands.upload_dataset,
-            dataset_commands.download_dataset,
-        ],
-        sdk_prefix="anyscale.llm.dataset",
-        sdk_commands=[
-            anyscale.llm.dataset.get,
-            anyscale.llm.dataset.upload,
-            anyscale.llm.dataset.download,
-        ],
-        models=[Dataset],
-    ),
     Module(
         title="Resource quotas",
         filename="resource-quotas.md",
