@@ -15,8 +15,16 @@ from anyscale._private.docgen.generator_legacy import (
     LegacySDK,
     parse_legacy_sdks,
 )
-from anyscale._private.models.model_base import ModelBaseType, ModelEnumType
-from anyscale.commands.util import AnyscaleCommand, LegacyAnyscaleCommand
+from anyscale._private.models.model_base import (
+    ModelBaseType,
+    ModelEnumType,
+    ResultIterator,
+)
+from anyscale.commands.util import (
+    AnyscaleCommand,
+    DeprecatedAnyscaleCommand,
+    LegacyAnyscaleCommand,
+)
 
 
 ModelType = Union[ModelBaseType, ModelEnumType]
@@ -46,6 +54,20 @@ CUSTOMER_HOSTED_QUALIFIER = (
 )
 
 
+def _escape_mdx_content(text: str) -> str:
+    """Escape content for MDX compatibility.
+
+    This function escapes angle brackets that could be interpreted as HTML tags
+    by MDX, converting them to escaped versions.
+    """
+    import re
+
+    # Escape angle brackets that look like HTML tags but are meant as literal text
+    # This pattern matches <word> or <word-with-hyphens> but not actual markdown/HTML
+    text = re.sub(r"<([a-zA-Z][a-zA-Z0-9\-]*?)>", r"\\<\1\\>", text)
+    return text
+
+
 @dataclass
 class Module:
     title: str
@@ -212,26 +234,19 @@ class MarkdownGenerator:
         if origin is Union:
             return " | ".join(self._model_type_to_string(arg) for arg in args)
 
-        if origin is dict:
-            arg_str = ", ".join([self._model_type_to_string(arg) for arg in args])
-            if args:
-                return f"Dict[{arg_str}]"
-            else:
-                return "Dict"
+        origin_name_map = {
+            dict: "Dict",
+            list: "List",
+            tuple: "Tuple",
+            ResultIterator: "ResultIterator",
+        }
 
-        if origin is list:
+        if origin in origin_name_map:
             arg_str = ", ".join([self._model_type_to_string(arg) for arg in args])
             if arg_str:
-                return f"List[{arg_str}]"
+                return f"{origin_name_map[origin]}[{arg_str}]"
             else:
-                return "List"
-
-        if origin is tuple:
-            arg_str = ", ".join([self._model_type_to_string(arg) for arg in args])
-            if arg_str:
-                return f"Tuple[{arg_str}]"
-            else:
-                return "Tuple"
+                return origin_name_map[origin]
 
         raise NotImplementedError(f"Unhandled type: {t}")
 
@@ -276,12 +291,13 @@ class MarkdownGenerator:
             - __doc_py_example__ (required in sdks)
             - __doc_cli_example__ (required for models and cli commands)
         """
+        skip_py_example: bool = getattr(t, "__skip_py_example__", False)
         yaml_example: Optional[str] = getattr(t, "__doc_yaml_example__", None)
         py_example: Optional[str] = getattr(t, "__doc_py_example__", None)
         cli_example: Optional[str] = getattr(t, "__doc_cli_example__", None)
 
         if isinstance(t, ModelBaseType):
-            if not py_example:
+            if not skip_py_example and not py_example:
                 raise ValueError(
                     f"Model '{t.__name__}' is missing a '__doc_py_example__'."
                 )
@@ -289,13 +305,20 @@ class MarkdownGenerator:
                 raise ValueError(
                     f"Config model '{t.__name__}' is missing a '__doc_yaml_example__'."
                 )
-        if isinstance(t, AnyscaleCommand) and not cli_example:
+        if (
+            isinstance(
+                t, (AnyscaleCommand, DeprecatedAnyscaleCommand, LegacyAnyscaleCommand)
+            )
+            and not cli_example
+        ):
             raise ValueError(
                 f"CLI command '{t.name}' is missing a '__doc_cli_example__'."
             )
         if (
             not isinstance(t, ModelBaseType)
-            and not isinstance(t, AnyscaleCommand)
+            and not isinstance(
+                t, (AnyscaleCommand, DeprecatedAnyscaleCommand, LegacyAnyscaleCommand)
+            )
             and not py_example
         ):
             raise ValueError(
@@ -309,8 +332,10 @@ class MarkdownGenerator:
             try:
                 yaml.safe_load(yaml_example)
             except Exception as e:  # noqa: BLE001
+                # For CLI commands, use t.name; for SDK functions/models, use t.__name__
+                name = getattr(t, "name", getattr(t, "__name__", str(t)))
                 raise ValueError(
-                    f"'{t.__name__}.__doc_yaml_example__' is not valid YAML syntax"
+                    f"'{name}.__doc_yaml_example__' is not valid YAML syntax"
                 ) from e
 
             yaml_example = yaml_example.strip("\n")
@@ -322,8 +347,10 @@ class MarkdownGenerator:
             try:
                 ast.parse(py_example)
             except Exception as e:  # noqa: BLE001
+                # For CLI commands, use t.name; for SDK functions/models, use t.__name__
+                name = getattr(t, "name", getattr(t, "__name__", str(t)))
                 raise ValueError(
-                    f"'{t.__name__}.__doc_py_example__' is not valid Python syntax"
+                    f"'{name}.__doc_py_example__' is not valid Python syntax"
                 ) from e
 
             py_example = py_example.strip("\n")
@@ -370,24 +397,25 @@ class MarkdownGenerator:
                         f"Model '{t.__name__}' is missing a docstring for field '{field.name}'"
                     )
 
-                md += f"- **`{field.name}` ({self._model_type_to_string(field.type)})**: {docstring}\n"
+                md += f"- **`{field.name}` ({self._model_type_to_string(field.type)})**: {_escape_mdx_content(docstring)}\n"
 
                 customer_hosted_only = field.metadata.get("customer_hosted_only", False)
                 if customer_hosted_only:
                     md += f"  - {CUSTOMER_HOSTED_QUALIFIER}\n"
             md += "\n\n"
 
-            md += "#### Python Methods\n\n"
-            md += "```python\n"
-            if t.__name__.endswith("Config"):
-                # Only include constructor docs for config models.
-                md += f"def __init__(self, **fields) -> {t.__name__}\n"
-                md += '    """Construct a model with the provided field values set."""\n\n'
-                md += f"def options(self, **fields) -> {t.__name__}\n"
-                md += '    """Return a copy of the model with the provided field values overwritten."""\n\n'
-            md += "def to_dict(self) -> Dict[str, Any]\n"
-            md += '    """Return a dictionary representation of the model."""\n'
-            md += "```\n"
+            if not getattr(t, "__skip_py_example__", False):
+                md += "#### Python Methods\n\n"
+                md += "```python\n"
+                if t.__name__.endswith("Config"):
+                    # Only include constructor docs for config models.
+                    md += f"def __init__(self, **fields) -> {t.__name__}\n"
+                    md += '    """Construct a model with the provided field values set."""\n\n'
+                    md += f"def options(self, **fields) -> {t.__name__}\n"
+                    md += '    """Return a copy of the model with the provided field values overwritten."""\n\n'
+                md += "def to_dict(self) -> Dict[str, Any]\n"
+                md += '    """Return a dictionary representation of the model."""\n'
+                md += "```\n"
 
             md += self._gen_example_tabs(t)
         elif isinstance(t, ModelEnumType):
@@ -400,7 +428,7 @@ class MarkdownGenerator:
 
         return md
 
-    def _gen_markdown_for_cli_command(
+    def _gen_markdown_for_cli_command(  # noqa: PLR0912
         self, c: click.Command, *, cli_prefix: str
     ) -> str:
         """Generate a markdown section for a CLI command.
@@ -425,9 +453,31 @@ class MarkdownGenerator:
             else:
                 new_c = c.get_new_cli()
                 new_cli_prefix = c.get_new_prefix()
-                md += ":::warning\n"
-                md += f"This command is deprecated. Upgrade to [{new_cli_prefix} {new_c.name}]({self._get_cli_anchor(new_c, new_cli_prefix)}). \n"
-                md += ":::\n"
+                if new_c and new_cli_prefix:
+                    md += ":::warning\n"
+                    md += f"This command is deprecated. Upgrade to [{new_cli_prefix} {new_c.name}]({self._get_cli_anchor(new_c, new_cli_prefix)}). \n"
+                    md += ":::\n"
+        elif isinstance(c, DeprecatedAnyscaleCommand):
+            md = f'### `{cli_prefix} {c.name}` <span class="label-h3 label-deprecated">Deprecated</span>\n'
+            md += ":::warning[Deprecated]\n"
+            # Build deprecation message similar to the command itself
+            parts = []
+            if hasattr(c, "__deprecation_message__") and c.__deprecation_message__:
+                parts.append(c.__deprecation_message__)
+            else:
+                parts.append(f"Command '{c.name}' is deprecated")
+
+            if hasattr(c, "__removal_date__") and c.__removal_date__:
+                date_str = c._format_removal_date(c.__removal_date__)  # noqa: SLF001
+                if date_str:
+                    parts.append(f"and will be removed on {date_str}")
+
+            if hasattr(c, "__alternative__") and c.__alternative__:
+                parts.append(f"Please {c.__alternative__}")
+
+            deprecation_msg = ". ".join(parts) + "."
+            md += deprecation_msg + "\n"
+            md += ":::\n"
         elif isinstance(c, AnyscaleCommand) and c.is_alpha:
             md = f'### `{cli_prefix} {c.name}` <span class="label-h3 label-alpha">Alpha</span>\n'
             md += ":::warning\n"
@@ -465,7 +515,8 @@ class MarkdownGenerator:
             md += "\n"
 
         should_have_example = not (
-            isinstance(c, LegacyAnyscaleCommand) or cli_prefix in CLI_NO_EXAMPLES
+            isinstance(c, (LegacyAnyscaleCommand, DeprecatedAnyscaleCommand))
+            or cli_prefix in CLI_NO_EXAMPLES
         )
         has_cli_example = hasattr(c, "__doc_cli_example__")
         if should_have_example or has_cli_example:
@@ -545,7 +596,7 @@ class MarkdownGenerator:
             md += ":::warning[Limited support]\n"
             md += "This command is not actively maintained. Use with caution.\n"
         md += ":::\n"
-        md += legacy_sdk.docstring + "\n"
+        md += _escape_mdx_content(legacy_sdk.docstring) + "\n"
 
         return md
 
@@ -555,7 +606,7 @@ class MarkdownGenerator:
         The sections will be:
             - All fields and their types
         """
-        md = f"### `{legacy_model.name}` <span class='label-h3 label-legacy'>Legacy</span>\n"
-        md += legacy_model.docstring + "\n"
+        md = f"### `{legacy_model.name}` <span class='label-h3 label-legacy'>Legacy</span> {{#{legacy_model.name.lower()}-legacy}}\n"
+        md += _escape_mdx_content(legacy_model.docstring) + "\n"
 
         return md
