@@ -6,6 +6,7 @@ from anyscale.sdk.anyscale_client.models.cluster_environment_build import (
 )
 
 
+DEFAULT_APP_CONFIG_ID_PREFIX = "DEFAULT_APP_CONFIG_ID"
 IMAGE_URI_PATTERN = "[registry_host/]user_name/repository[:tag][@digest]"
 IMAGE_URI_PATTERN_RE = re.compile(
     r"^"
@@ -23,6 +24,7 @@ IMAGE_URI_PATTERN_RE = re.compile(
 )
 
 ANYSCALE_CLUSTER_ENV_PREFIX = "anyscale/image/"
+DEFAULT_IMAGE_URI_PREFIX = "anyscale/ray"
 
 
 class ImageURI:
@@ -47,6 +49,13 @@ class ImageURI:
     def _is_byod_build(cls, build: ClusterEnvironmentBuild) -> bool:
         return build.is_byod or (not build.config_json and not build.containerfile)
 
+    @classmethod
+    def _is_default_build(cls, build: ClusterEnvironmentBuild) -> bool:
+        return bool(
+            isinstance(build.cluster_environment_id, str)
+            and build.cluster_environment_id.startswith(DEFAULT_APP_CONFIG_ID_PREFIX)
+        )
+
     @classmethod
     def from_cluster_env_build(
         cls,
@@ -59,6 +68,8 @@ class ImageURI:
                 return ImageURI.from_str(build.docker_image_name)
             else:
                 return ImageURI.from_str("")
+        elif cls._is_default_build(build):
+            return ImageURI.from_str(build.docker_image_name)
         else:
             image_uri_str = (
                 ANYSCALE_CLUSTER_ENV_PREFIX + f"{cluster_env.name}:{build.revision}"
@@ -81,6 +92,10 @@ class ImageURI:
         """Check if the image URI is a cluster environment image."""
         return self.image_uri.startswith(ANYSCALE_CLUSTER_ENV_PREFIX)
 
+    def is_default_image(self) -> bool:
+        """Check if the image URI is a default image."""
+        return self.image_uri.startswith(DEFAULT_IMAGE_URI_PREFIX)
+
     def to_cluster_env_identifier(self) -> str:
         assert self.is_cluster_env_image()
         identifier = self.image_uri.split("/")[2]
