@@ -1,3 +1,5 @@
+from typing import Optional
+
 from anyscale._private.sdk import sdk_command
 from anyscale.aggregated_instance_usage._private.aggregated_instance_usage_sdk import (
     PrivateAggregatedInstanceUsageSDK,
@@ -33,8 +35,10 @@ _DOWNLOAD_ARG_DOCSTRINGS = {"filters": "The filter of the instance usage to down
     arg_docstrings=_DOWNLOAD_ARG_DOCSTRINGS,
 )
 def download_csv(
-    filters: DownloadCSVFilters, *, _sdk: PrivateAggregatedInstanceUsageSDK
+    filters: DownloadCSVFilters,
+    *,
+    _private_sdk: Optional[PrivateAggregatedInstanceUsageSDK] = None
 ) -> str:
     """Download an aggregated instance usage report as a zipped CSV to the provided directory.
     """
-    return _sdk.download_csv(filters)
+    return _private_sdk.download_csv(filters)  # type: ignore
