@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import click
 
@@ -6,6 +6,7 @@ from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
 from anyscale.sdk.anyscale_client import ClusterEnvironmentBuild
+from anyscale.sdk.anyscale_client.api.default_api import DefaultApi as SDKDefaultApi
 from anyscale.shared_anyscale_utils.utils.byod import is_byod_id
 from anyscale.util import get_endpoint, get_ray_and_py_version_for_default_cluster_env
 
@@ -15,7 +16,7 @@ log = BlockLogger()
 
 def get_default_cluster_env_build(
     api_client: Optional[DefaultApi] = None,
-    anyscale_api_client: Optional[DefaultApi] = None,
+    anyscale_api_client: Optional[Union[DefaultApi, SDKDefaultApi]] = None,
 ) -> ClusterEnvironmentBuild:
     ray_version, py_version = get_ray_and_py_version_for_default_cluster_env()
 
@@ -38,7 +39,8 @@ def get_default_cluster_env_build(
 
 
 def get_build_from_cluster_env_identifier(
-    cluster_env_identifier: str, anyscale_api_client: Optional[DefaultApi] = None,
+    cluster_env_identifier: str,
+    anyscale_api_client: Optional[Union[DefaultApi, SDKDefaultApi]] = None,
 ) -> ClusterEnvironmentBuild:
     """
     Get a build id from a cluster environment identifier of form `my_cluster_env:1` or
@@ -103,7 +105,8 @@ def get_build_from_cluster_env_identifier(
 
 
 def get_cluster_env_from_name(
-    cluster_env_name: str, anyscale_api_client: Optional[DefaultApi] = None,
+    cluster_env_name: str,
+    anyscale_api_client: Optional[Union[DefaultApi, SDKDefaultApi]] = None,
 ) -> ClusterEnvironmentBuild:
     """
     Get id of the cluster env (not build) given the name.
@@ -111,6 +114,7 @@ def get_cluster_env_from_name(
 
     if anyscale_api_client is None:
         anyscale_api_client = get_auth_api_client().anyscale_api_client
+    assert anyscale_api_client is not None
     cluster_envs = anyscale_api_client.search_cluster_environments(
         {"name": {"equals": cluster_env_name}, "paging": {"count": 1}}
     ).results
@@ -123,7 +127,7 @@ def get_cluster_env_from_name(
 
 def list_builds(
     cluster_env_id: str,
-    anyscale_api_client: Optional[DefaultApi] = None,
+    anyscale_api_client: Optional[Union[DefaultApi, SDKDefaultApi]] = None,
     max_items: Optional[int] = None,
 ) -> List[ClusterEnvironmentBuild]:
     """
@@ -161,6 +165,7 @@ def validate_successful_build(
 
     if anyscale_api_client is None:
         anyscale_api_client = get_auth_api_client().anyscale_api_client
+    assert anyscale_api_client is not None
     build = anyscale_api_client.get_cluster_environment_build(build_id).result
     if build.status != "succeeded":
         cluster_env = anyscale_api_client.get_cluster_environment(
