@@ -4,7 +4,7 @@ Commands to interact with the Anyscale Session Operatons API
 
 import click
 
-from anyscale.api import get_anyscale_api_client
+from anyscale.authenticate import get_auth_api_client
 from anyscale.formatters import common_formatter
 
 
@@ -23,6 +23,6 @@ def get_session_operation(session_operation_id: str,) -> None:
     """Retrieves a Session Operation.
     """
 
-    api_client = get_anyscale_api_client()
+    api_client = get_auth_api_client().anyscale_api_client
     response = api_client.get_session_operation(session_operation_id)
     print(common_formatter.prettify_json(response.to_dict()))
