@@ -15,6 +15,7 @@ from anyscale.commands.util import AnyscaleCommand, OptionPromptNull
 from anyscale.controllers.cloud_controller import CloudController
 from anyscale.util import (
     allow_optional_file_storage,
+    SharedStorageType,
     validate_non_negative_arg,
 )
 
@@ -152,6 +153,14 @@ def default_region(provider: str) -> str:
         "disable this and instead manually grant users permissions to the cloud."
     ),
 )
+@click.option(
+    "--shared-storage",
+    required=False,
+    type=click.Choice([e.value for e in SharedStorageType], case_sensitive=False),
+    default=SharedStorageType.OBJECT_STORAGE.value,
+    show_default=True,
+    help="The type of shared storage to use for the cloud. Use 'object-storage' for cloud bucket-based storage (e.g., S3, GCS), or 'nfs' for network file systems.",
+)
 def setup_cloud(  # noqa: PLR0913
     provider: str,
     region: str,
@@ -162,8 +171,12 @@ def setup_cloud(  # noqa: PLR0913
     enable_head_node_fault_tolerance: bool,
     yes: bool,
     disable_auto_add_user: bool,
+    shared_storage: str,
 ) -> None:
     # TODO (congding): remove `anyscale_managed` in the future, now keeping it for compatibility
+
+    # Convert string to enum for type safety
+    shared_storage_type = SharedStorageType(shared_storage)
     if provider == "aws":
         CloudController().setup_managed_cloud(
             provider=provider,
@@ -174,6 +187,7 @@ def setup_cloud(  # noqa: PLR0913
             enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
             yes=yes,
             auto_add_user=(not disable_auto_add_user),
+            shared_storage=shared_storage_type,
         )
     elif provider == "gcp":
         if not project_id:
@@ -193,6 +207,7 @@ def setup_cloud(  # noqa: PLR0913
             enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
             yes=yes,
             auto_add_user=(not disable_auto_add_user),
+            shared_storage=shared_storage_type,
         )
 
 
@@ -229,17 +244,84 @@ def list_cloud(name: Optional[str], cloud_id: Optional[str], max_items: int,) ->
     )
 
 
+@cloud_cli.group("resource", help="Manage the configuration for a cloud resource.")
+def cloud_resource_group() -> None:
+    pass
+
+
 @cloud_cli.group("config", help="Manage the configuration for a cloud.")
 def cloud_config_group() -> None:
     pass
 
 
+@cloud_resource_group.command(
+    name="create",
+    help="Create a new cloud resource in an existing cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.CLOUD_RESOURCE_CREATE_EXAMPLE,
+    is_alpha=True,
+)
+@click.option(
+    "--cloud",
+    help="The name of the cloud to add the new resource to.",
+    type=str,
+    required=True,
+)
+@click.option(
+    "--file",
+    "-f",
+    help="Path to a YAML file defining the cloud resource. Schema: https://docs.anyscale.com/reference/cloud/#cloudresource.",
+    required=True,
+)
+@click.option(
+    "--skip-verification",
+    is_flag=True,
+    default=False,
+    help="Skip cloud resource verification.",
+)
+@click.option(
+    "--yes", "-y", is_flag=True, default=False, help="Skip asking for confirmation."
+)
+def cloud_resource_create(
+    cloud: str, file: str, skip_verification: bool, yes: bool,
+) -> None:
+    try:
+        CloudController().create_cloud_resource(cloud, file, skip_verification, yes)
+    except click.ClickException as e:
+        print(e)
+
+
+@cloud_resource_group.command(
+    name="delete",
+    help="Remove a cloud resource from an existing cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.CLOUD_RESOURCE_DELETE_EXAMPLE,
+    is_alpha=True,
+)
+@click.option(
+    "--cloud",
+    help="The name of the cloud to remove the resource from.",
+    type=str,
+    required=True,
+)
+@click.option(
+    "--resource",
+    help="The name of the cloud resource to remove.",
+    type=str,
+    required=True,
+)
+@click.option(
+    "--yes", "-y", is_flag=True, default=False, help="Skip asking for confirmation."
+)
+def cloud_resource_delete(cloud: str, resource: str, yes: bool,) -> None:
+    try:
+        CloudController().remove_cloud_resource(cloud, resource, yes)
+    except click.ClickException as e:
+        print(e)
+
+
 @cloud_cli.command(
-    name="update",
-    help=(
-        # TODO(janet): Update this help text when the -o option is un-hidden.
-        "Update a managed cloud to the latest configuration. Only applicable for anyscale managed clouds."
-    ),
+    name="update", help=("Update a cloud."),
 )
 @click.argument("cloud-name", required=False)
 @click.option(
@@ -277,11 +359,16 @@ def cloud_config_group() -> None:
     ),
 )
 @click.option(
-    "--file",
+    "--resources-file",
     "-f",
-    help="YAML file containing the updated cloud spec.",
+    help="EXPERIMENTAL: Path to a YAML file defining a list of cloud resources. Schema: https://docs.anyscale.com/reference/cloud/#cloudresource.",
     required=False,
-    hidden=True,
+)
+@click.option(
+    "--skip-verification",
+    is_flag=True,
+    default=False,
+    help="Skip cloud resource verification.",
 )
 def cloud_update(  # noqa: PLR0913
     cloud_name: Optional[str],
@@ -291,17 +378,23 @@ def cloud_update(  # noqa: PLR0913
     enable_head_node_fault_tolerance: bool,
     yes: bool,
     enable_auto_add_user: Optional[bool],
-    file: Optional[str],
+    resources_file: Optional[str],
+    skip_verification: bool,
 ) -> None:
-    if file:
-        CloudController().update_cloud_deployments(file)
-        return
-
     if cloud_name and name and cloud_name != name:
         raise click.ClickException(
             "The positional argument CLOUD_NAME and the keyword argument --name "
             "were both provided. Please only provide one of these two arguments."
         )
+    if resources_file:
+        CloudController().update_cloud_resources(
+            cloud_name=cloud_name or name,
+            cloud_id=cloud_id,
+            resources_file=resources_file,
+            skip_verification=skip_verification,
+            yes=yes,
+        )
+        return
     if enable_head_node_fault_tolerance and (enable_auto_add_user is not None):
         raise click.ClickException(
             "Please only specify either --enable-head-node-fault-tolerance or "
@@ -345,14 +438,17 @@ def cloud_config_get(
 
 
 @cloud_config_group.command(
-    "update", help="Update the current configuration for a cloud."
+    "update",
+    help="Update the current configuration for a cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.CLOUD_CONFIG_UPDATE_EXAMPLE,
 )
 @click.argument("cloud-name", required=False)
 @click.option("--name", "-n", help="Update configuration of cloud by name.", type=str)
 @click.option(
     "--cloud-id",
     "--id",
-    help="Cloud id to get details about. Alternative to cloud name.",
+    help="Cloud id to update. Alternative to cloud name.",
     required=False,
 )
 @click.option(
@@ -370,6 +466,12 @@ def cloud_config_get(
         "extra data transfer cost from the cloud provider by enabling this feature."
     ),
 )
+@click.option(
+    "--enable-system-cluster/--disable-system-cluster",
+    default=None,
+    help="Enable or disable system cluster functionality.",
+    required=False,
+)
 @click.option(
     "--spec-file",
     type=str,
@@ -381,14 +483,25 @@ def cloud_config_update(
     name: Optional[str],
     cloud_id: Optional[str],
     enable_log_ingestion: Optional[bool],
+    enable_system_cluster: Optional[bool],
     spec_file: Optional[str],
 ) -> None:
-    if any([enable_log_ingestion is not None]) and spec_file:
+    if cloud_name and name and cloud_name != name:
         raise click.ClickException(
-            "Please provide only one of the following arguments: --enable-log-ingestion, --disable-log-ingestion, --spec-file."
+            "The positional argument CLOUD_NAME and the keyword argument --name "
+            "were both provided. Please only provide one of these two arguments."
         )
 
-    if any([enable_log_ingestion is not None]):
+    passed_enable_disable_flags = any(
+        [enable_log_ingestion is not None, enable_system_cluster is not None]
+    )
+    if passed_enable_disable_flags and spec_file:
+        raise click.ClickException(
+            "Invalid combination of arguments: --spec-file should not be provided with any other enable/disable flags."
+        )
+
+    if passed_enable_disable_flags:
+        # Handle log ingestion configuration
         # TODO: enable_log_ingestion should be unified into cloud deployment config.
         if enable_log_ingestion is True:
             consent_message = click.prompt(
@@ -403,7 +516,7 @@ def cloud_config_update(
                 raise click.ClickException(
                     'You must type "consent" to enable log ingestion.'
                 )
-        if enable_log_ingestion is False:
+        elif enable_log_ingestion is False:
             confirm_response = click.confirm(
                 "--disable-log-ingestion is specified. Please note the logs that's "
                 "already ingested will not be deleted. Existing clusters will not stop"
@@ -419,13 +532,38 @@ def cloud_config_update(
             cloud_id=cloud_id,
             enable_log_ingestion=enable_log_ingestion,
         )
+
+        # Handle system cluster configuration
+        if enable_system_cluster is True:
+            confirm_response = click.confirm(
+                "--enable-system-cluster is specified. Please note that this will enable "
+                "system cluster functionality for the cloud and will incur extra cost. "
+                "Are you sure you want to enable system cluster?"
+            )
+        elif enable_system_cluster is False:
+            confirm_response = click.confirm(
+                "--disable-system-cluster is specified. This will disable system cluster "
+                "functionality for the cloud. Please note that this will not terminate "
+                "the system cluster if it is currently running. "
+                "Are you sure you want to disable system cluster?"
+            )
+        if enable_system_cluster is not None and not confirm_response:
+            raise click.ClickException(
+                f"You must confirm to {'enable' if enable_system_cluster else 'disable'} system cluster."
+            )
+
+        CloudController().update_system_cluster_config(
+            cloud_name=cloud_name or name,
+            cloud_id=cloud_id,
+            system_cluster_enabled=enable_system_cluster,
+        )
     elif spec_file:
         CloudController().update_cloud_config(
             cloud_name=cloud_name or name, cloud_id=cloud_id, spec_file=spec_file,
         )
     else:
         raise click.ClickException(
-            "Please provide at least one of the following arguments: --enable-log-ingestion, --disable-log-ingestion."
+            "Please provide at least one of the following arguments: --enable-log-ingestion, --disable-log-ingestion, --enable-system-cluster, --disable-system-cluster, --spec-file."
         )
 
 
@@ -561,7 +699,7 @@ def cloud_config_update(
 )
 @click.option(
     "--cloud-storage-bucket-name",
-    help="A fully qualified storage bucket name for cloud storage, e.g. s3://bucket-name, gs://bucket-name, or azure://bucket-name.",
+    help="A fully qualified storage bucket name for cloud storage, e.g. s3://bucket-name, gs://bucket-name, or abfss://bucket-name@account.dfs.core.windows.net.",
     required=False,
     type=str,
 )
@@ -590,6 +728,18 @@ def cloud_config_update(
     required=False,
     type=str,
 )
+@click.option(
+    "--persistent-volume-claim",
+    help="For Kubernetes deployments only, the name of the persistent volume claim used to mount shared storage into pods. Mutually exclusive with NFS configurations.",
+    required=False,
+    type=str,
+)
+@click.option(
+    "--csi-ephemeral-volume-driver",
+    help="For Kubernetes deployments only, the CSI ephemeral volume driver used to mount shared storage into pods. Mutually exclusive with NFS configurations.",
+    required=False,
+    type=str,
+)
 @click.option(
     "--memorystore-instance-name",
     help="Memorystore instance name for GCP clouds",
@@ -675,6 +825,8 @@ def register_cloud(  # noqa: PLR0913, PLR0912, C901
     cloud_storage_bucket_region: Optional[str],
     nfs_mount_target: List[str],
     nfs_mount_path: str,
+    persistent_volume_claim: Optional[str],
+    csi_ephemeral_volume_driver: Optional[str],
     memorystore_instance_name: str,
     host_project_id: Optional[str],
     kubernetes_zones: Optional[str],
@@ -686,6 +838,30 @@ def register_cloud(  # noqa: PLR0913, PLR0912, C901
     enable_auto_add_user: bool,
 ) -> None:
     missing_args: List[str] = []
+
+    # Validate K8S-only storage flags
+    if (
+        persistent_volume_claim or csi_ephemeral_volume_driver
+    ) and compute_stack != ComputeStack.K8S:
+        raise click.ClickException(
+            "--persistent-volume-claim and --csi-ephemeral-volume-driver are only supported with --compute-stack=k8s"
+        )
+
+    # Validate mutual exclusivity of storage configurations
+    storage_configs = []
+    if nfs_mount_target or nfs_mount_path:
+        storage_configs.append("NFS")
+    if persistent_volume_claim:
+        storage_configs.append("persistent volume claim")
+    if csi_ephemeral_volume_driver:
+        storage_configs.append("CSI ephemeral volume driver")
+
+    if len(storage_configs) > 1:
+        raise click.ClickException(
+            f"Storage configurations are mutually exclusive. Found: {', '.join(storage_configs)}. "
+            "Please specify only one of: --nfs-mount-target/--nfs-mount-path, --persistent-volume-claim, or --csi-ephemeral-volume-driver"
+        )
+
     if provider == "aws":
         if s3_bucket_id and not cloud_storage_bucket_name:
             cloud_storage_bucket_name = s3_bucket_id
@@ -748,6 +924,8 @@ def register_cloud(  # noqa: PLR0913, PLR0912, C901
             skip_verifications=skip_verifications,
             auto_add_user=enable_auto_add_user,
             external_id=external_id,
+            persistent_volume_claim=persistent_volume_claim,
+            csi_ephemeral_volume_driver=csi_ephemeral_volume_driver,
         )
     elif provider == "gcp":
         if filestore_instance_id and not file_storage_id:
@@ -860,6 +1038,8 @@ def register_cloud(  # noqa: PLR0913, PLR0912, C901
             yes=yes,
             skip_verifications=skip_verifications,
             auto_add_user=enable_auto_add_user,
+            persistent_volume_claim=persistent_volume_claim,
+            csi_ephemeral_volume_driver=csi_ephemeral_volume_driver,
         )
     elif provider in ("azure", "generic"):
         # For the 'generic' provider type, for the time being, most fields are optional; only 'name', 'provider', and 'compute-stack' are required.
@@ -881,7 +1061,10 @@ def register_cloud(  # noqa: PLR0913, PLR0912, C901
             cloud_storage_bucket_region=cloud_storage_bucket_region,
             nfs_mount_targets=list(nfs_mount_target) if nfs_mount_target else [],
             nfs_mount_path=nfs_mount_path,
+            persistent_volume_claim=persistent_volume_claim,
+            csi_ephemeral_volume_driver=csi_ephemeral_volume_driver,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
+            anyscale_operator_iam_identity=anyscale_operator_iam_identity,
         )
 
     else:
@@ -1154,14 +1337,16 @@ def get_cloud(
             log.error("Cloud not found.")
             return
 
-        # Include all cloud deployments for the cloud.
-        cloud_deployments = CloudController().get_cloud_deployments(cloud_id=cloud.id)
+        # Include all cloud resources for the cloud.
+        cloud_resources = CloudController().get_formatted_cloud_resources(
+            cloud_id=cloud.id
+        )
         result = {
             "name": cloud.name,
             "id": cloud.id,
             "created_at": cloud.created_at,
             "is_default": cloud.is_default,
-            "deployments": cloud_deployments.get("deployments", []),
+            "resources": cloud_resources,
         }
 
         if output:
