@@ -322,135 +322,6 @@ $ anyscale machine-pool detach --name can-testing --cloud my-cloud
 Detached machine pool 'can-testing' from cloud 'my-cloud'.
 """
 
-LLM_MODELS_GET_EXAMPLE = """
-$ anyscale llm model get --model-id my-model-id
-Output
-{
-    'id': 'my-model-id',
-    'base_model_id': 'meta-llama/Meta-Llama-3-8B',
-    'storage_uri': 'gs://my_bucket/my_folder',
-    'ft_type': 'LORA',
-    'cloud_id': 'cld_tffbxe9ia5phqr1unxhz4f7e1e',
-    'project_id': 'prj_dqb6ha67zubz3gdlvn2tmmglb8',
-    'created_at': 1725563985,
-    'creator': 'test@anyscale.com',
-    'job_id': 'N/A',
-    'workspace_id': 'expwrk_yje3t8twim18iuta9r45gwcgcn',
-    'generation_config': {
-        'prompt_format': {
-            'system': '<|start_header_id|>system<|end_header_id|>\\n\\n{instruction}<|eot_id|>',
-            'assistant': '<|start_header_id|>assistant<|end_header_id|>\\n\\n{instruction}<|eot_id|>',
-            'trailing_assistant': '<|start_header_id|>assistant<|end_header_id|>\\n\\n',
-            'user': '<|start_header_id|>user<|end_header_id|>\\n\\n{instruction}<|eot_id|>',
-            'bos': '<|begin_of_text|>',
-            'default_system_message': '',
-            'add_system_tags_even_if_message_is_empty': False,
-            'system_in_user': False,
-            'system_in_last_user': False,
-            'strip_whitespace': True
-        },
-        'stopping_sequences': None
-    }
-}
-"""
-
-LLM_MODELS_LIST_EXAMPLE = """
-$ anyscale llm model list --cloud-id cld_1j41ls4gwkga4pwp8nbql6f239 --project_id prj_i4wy1t442cbe2sthxp61dmtkbh --max-items 2
-Output
-[
-    {
-        'id': 'meta-llama/Meta-Llama-3-8B-Instruct:test:bnkve',
-        'base_model_id': 'meta-llama/Meta-Llama-3-8B-Instruct',
-        'storage_uri': 's3://anyscale-production-data-cld-1j41ls4gwkga4pwp...',
-        'ft_type': 'LORA',
-        'cloud_id': 'cld_1j41ls4gwkga4pwp8nbql6f239',
-        'project_id': 'prj_i4wy1t442cbe2sthxp61dmtkbh',
-        'created_at': 1725572462,
-        'creator': 'test@anyscale.com',
-        'job_id': 'N/A',
-        'workspace_id': 'expwrk_bqld1y579g3clukr49rsnd7i5m',
-        'generation_config': '{"prompt_format": {"system": "<|start_header_id|>s...'
-    },
-    {
-        'id': 'neuralmagic/Meta-Llama-3.1-8B-Instruct-FP8:test:czcal',
-        'base_model_id': 'neuralmagic/Meta-Llama-3.1-8B-Instruct-FP8',
-        'storage_uri': 'gs://storage-bucket-cld-tffbxe9ia5phqr1unxhz4f7e1e...',
-        'ft_type': 'LORA',
-        'cloud_id': 'cld_1j41ls4gwkga4pwp8nbql6f239',
-        'project_id': 'prj_i4wy1t442cbe2sthxp61dmtkbh',
-        'created_at': 1725563985,
-        'creator': 'test@anyscale.com',
-        'job_id': 'N/A',
-        'workspace_id': 'expwrk_yje3t8twim18iuta9r45gwcgcn',
-        'generation_config': '{"prompt_format": {"system": "<|start_header_id|>s...'
-    }
-]
-"""
-
-LLM_MODELS_DELETE_EXAMPLE = """
-$ anyscale llm model delete --model-id my-model-id
-Output
-{'id': 'my-model-id', 'deleted_at': 1725572462}
-"""
-
-LLM_DATASET_GET_EXAMPLE = """
-$ anyscale llm dataset get john_doe/viggo/train.jsonl
-Dataset(
-    id='dataset_123',
-    name='john_doe/viggo/train.jsonl',
-    filename='train.jsonl',
-    storage_uri='s3://anyscale-test-data-cld-123/org_123/cld_123/datasets/dataset_123/3/john_doe/viggo/train.jsonl',
-    version=3,
-    num_versions=3,
-    created_at=datetime.datetime(2024, 1, 1, 0, 0, tzinfo=tzutc()),
-    creator_id='usr_123',
-    project_id='prj_123',
-    cloud_id='cld_123',
-    description=None
-)
-"""
-
-LLM_DATASET_UPLOAD_EXAMPLE = """
-$ anyscale llm dataset upload path/to/my_dataset.jsonl -n my_first_dataset
-
-0:00:00 100% ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ 5.1 MB / 5.1 MB Uploading '/path/to/my_dataset.jsonl'
-
-Upload complete!
-
-Dataset(
-    id='dataset_123',
-    name='my_first_dataset',
-    filename='my_dataset.jsonl',
-    storage_uri='s3://anyscale-test-data-cld-123/org_123/cld_123/datasets/dataset_123/1/my_dataset.jsonl',
-    version=1,
-    num_versions=1,
-    created_at=datetime.datetime(2024, 1, 1, 0, 0, tzinfo=tzutc()),
-    creator_id='usr_123',
-    project_id='prj_123',
-    cloud_id='cld_123',
-    description=None
-)
-"""
-
-LLM_DATASET_DOWNLOAD_EXAMPLE = """
-$ anyscale llm dataset download train.jsonl
-0:00:00 100% ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ 711.0 kB / 711.0 kB Downloading 'train.jsonl'
-
-Download complete!
-
-{"messages":[{"content":"hi","role":"user"},{"content":"Hi! How can I help?","role":"assistant"}]}
-...
-{"messages":[{"content":"bye","role":"user"},{"content":"Goodbye!","role":"assistant"}]}
-"""
-
-LLM_DATASET_LIST_EXAMPLE = """
-$ anyscale llm dataset list
-ID         Name                   Description                       Created At             Num Versions
----------  ---------------------  --------------------------------  -------------------  --------------
-dataset_2  second                 second upload                     1/2/2024 12:00 PM              23
-dataset_1  first                  first upload                      1/1/2024 12:00 PM              13
-"""
-
 RESOURCE_QUOTAS_CREATE_EXAMPLE = """
 $ anyscale resource-quota create -n my-resource-quota --cloud my-cloud --project my-project --user-email someone@myorg.com --num-instances 100 --num-cpus 1000 --num-gpus 50 --num-accelerators A10G 10 --num-accelerators A100-80G 0
 (anyscale +2.5s) Name: my-resource-quota
@@ -627,6 +498,7 @@ $ anyscale organization-invitation delete --email test@anyscale.com
 (anyscale +0.6s) Organization invitation for test@anyscale.com deleted.
 """
 
+
 PROJECT_ADD_COLLABORATORS_EXAMPLE = """\
 $ anyscale project add-collaborators --cloud cloud_name --project project_name --users-file collaborators.yaml
 (anyscale +1.3s) Successfully added 3 collaborators to project project_name.
@@ -640,6 +512,32 @@ collaborators:
     permission_level: "owner"
 """
 
+
+PROJECT_GET_EXAMPLE = """\
+$ anyscale project get --id my-project-id
+"""
+
+
+PROJECT_LIST_EXAMPLE = """\
+$ anyscale project list --include-defaults --non-interactive --max-items 2
+"""
+
+
+PROJECT_CREATE_EXAMPLE = """\
+$ anyscale project create --name "my-project" --cloud "my-cloud-id"
+"""
+
+
+PROJECT_DELETE_EXAMPLE = """\
+$ anyscale project delete --id project-id
+"""
+
+
+PROJECT_GET_DEFAULT_EXAMPLE = """\
+$ anyscale project get-default --cloud my-cloud-id --json
+"""
+
+
 CLOUD_ADD_COLLABORATORS_EXAMPLE = """\
 $ anyscale cloud add-collaborators --cloud cloud_name --users-file collaborators.yaml
 (anyscale +1.3s) Successfully added 2 collaborators to cloud cloud_name.
@@ -651,6 +549,39 @@ collaborators:
     permission_level: "readonly"
 """
 
+
+CLOUD_RESOURCE_CREATE_EXAMPLE = """\
+$ anyscale cloud resource create --cloud my-cloud --file new-cloud-resource.yaml
+Successfully created cloud resource my-new-resource in cloud my-cloud.
+
+$ cat new-cloud-resource.yaml
+name: my-new-resource
+provider: AWS
+compute_stack: VM
+region: us-west-2
+networking_mode: PUBLIC
+object_storage:
+  bucket_name: s3://my-bucket
+file_storage:
+  file_storage_id: fs-123
+aws_config:
+  vpc_id: vpc-123
+  subnet_ids:
+  - subnet-123
+  security_group_ids:
+  - sg-123
+  anyscale_iam_role_id: arn:aws:iam::123456789012:role/anyscale-role-123
+  cluster_iam_role_id: arn:aws:iam::123456789012:role/cluster-role-123
+  memorydb_cluster_name: my-memorydb-cluster
+"""
+
+CLOUD_RESOURCE_DELETE_EXAMPLE = """\
+$ anyscale cloud resource delete --cloud my-cloud --resource my-resource
+Output
+Please confirm that you would like to remove resource my-resource from cloud my-cloud. [y/N]: y
+(anyscale +3.5s) Successfully removed resource my-resource from cloud my-cloud!
+"""
+
 CLOUD_GET_CLOUD_EXAMPLE = """\
 $ anyscale cloud get --name my-cloud
 id: cld_123
@@ -658,7 +589,7 @@ name: my-cloud
 created_at: 2022-10-18 05:12:13.335803+00:00
 is_default: true
 deployments:
-- cloud_deployment_id: cldrsrc_123
+- cloud_resource_id: cldrsrc_123
   name: vm-aws-us-west-2
   provider: AWS
   compute_stack: VM
@@ -690,6 +621,16 @@ is_default: true
 compute_stack: VM
 """
 
+CLOUD_CONFIG_UPDATE_EXAMPLE = """\
+$ anyscale cloud config update --cloud-id cloud_id --enable-log-ingestion --enable-system-cluster
+--enable-log-ingestion is specified. [...] If you are sure you want to enable this feature, please type "consent": consent
+Output
+(anyscale +7.3s) Successfully updated log ingestion configuration for cloud, cloud_id to True
+--enable-system-cluster is specified. [...] Are you sure you want to enable system cluster? [y/N]: y
+Output
+(anyscale +11.4s) Successfully enabled system cluster for cloud cloud_id
+"""
+
 CLOUD_TERMINATE_SYSTEM_CLUSTER_EXAMPLE = """\
 $ anyscale cloud terminate-system-cluster --cloud-id cloud_id --wait
 (anyscale +1.3s) Waiting for system cluster termination............
