@@ -8,7 +8,10 @@ import anyscale
 from anyscale.cli_logger import BlockLogger
 from anyscale.commands import command_examples
 from anyscale.commands.util import AnyscaleCommand, LegacyAnyscaleCommand
-from anyscale.compute_config import ComputeConfig
+from anyscale.compute_config.models import (
+    compute_config_type_from_yaml,
+    ComputeConfigVersion,
+)
 from anyscale.controllers.compute_config_controller import ComputeConfigController
 from anyscale.util import validate_non_negative_arg
 
@@ -105,7 +108,7 @@ def create_compute_config(
     if compute_config_file is not None:
         ComputeConfigController().create(compute_config_file, name)
     elif config_file is not None:
-        config = ComputeConfig.from_yaml(config_file)
+        config = compute_config_type_from_yaml(config_file)
         anyscale.compute_config.create(config, name=name)
     else:
         raise click.ClickException(
@@ -201,7 +204,7 @@ def list(  # noqa: A001
     help=(
         "Get the details of a compute config.\n\n"
         "The name can contain an optional version, e.g., 'name:version'. "
-        "If no version is provided, the latest one will be archived.\n\n"
+        "If no version is provided, the latest one will be returned.\n\n"
     ),
     cls=AnyscaleCommand,
     example=command_examples.COMPUTE_CONFIG_GET_EXAMPLE,
@@ -244,7 +247,7 @@ def get_compute_config(
             include_archived=include_archived,
         )
     else:
-        config: ComputeConfig = anyscale.compute_config.get(
+        config: ComputeConfigVersion = anyscale.compute_config.get(
             name=name, _id=cc_id, include_archived=include_archived,
         )
         stream = StringIO()
