@@ -8,6 +8,7 @@ from typing import Any, Optional
 import click
 
 from anyscale.cli_logger import BlockLogger
+from anyscale.commands.util import DeprecatedAnyscaleCommand
 from anyscale.controllers.list_controller import ListController
 
 
@@ -25,26 +26,40 @@ def list_cli() -> None:
     name="clouds",
     help="[DEPRECATED] List the clouds currently available in your account.",
     hidden=True,
+    cls=DeprecatedAnyscaleCommand,
+    removal_date="2025-10-01",
+    deprecation_message="`anyscale list clouds` has been deprecated",
+    alternative="use `anyscale cloud list` instead",
 )
 @click.option("--json", "show_json", help="Return the results in json", is_flag=True)
 def list_clouds(show_json: bool) -> None:
-    log.warning(
-        "`anyscale list clouds` has been deprecated. Please use `anyscale cloud list` instead."
-    )
+    """List the clouds currently available in your account.
+
+    DEPRECATED: This command will be removed on 2025-10-01.
+    Use 'anyscale cloud list' instead.
+    """
     list_controller = ListController()
     output = list_controller.list_clouds(json_format=show_json)
     print(output)
 
 
 @list_cli.command(
-    name="projects", help="[DEPRECATED] List all accessible projects.", hidden=True
+    name="projects",
+    help="[DEPRECATED] List all accessible projects.",
+    hidden=True,
+    cls=DeprecatedAnyscaleCommand,
+    removal_date="2025-10-01",
+    deprecation_message="`anyscale list projects` has been deprecated",
+    alternative="use `anyscale project list` instead",
 )
 @click.option("--json", "show_json", help="Return the results in json", is_flag=True)
 @click.pass_context
 def project_list(ctx: Any, show_json: bool) -> None:  # noqa: ARG001
-    log.warning(
-        "`anyscale list projects` has been deprecated. Please use `anyscale project list` instead."
-    )
+    """List all accessible projects.
+
+    DEPRECATED: This command will be removed on 2025-10-01.
+    Use 'anyscale project list' instead.
+    """
     list_controller = ListController()
     output = list_controller.list_projects(json_format=show_json)
     print(output)
@@ -54,6 +69,10 @@ def project_list(ctx: Any, show_json: bool) -> None:  # noqa: ARG001
     name="sessions",
     help="[DEPRECATED] List all clusters within the current project.",
     hidden=True,
+    cls=DeprecatedAnyscaleCommand,
+    removal_date="2025-10-01",
+    deprecation_message="`anyscale list sessions` has been deprecated",
+    alternative="use `anyscale cluster list` instead",
 )
 @click.option(
     "--name",
@@ -65,9 +84,11 @@ def project_list(ctx: Any, show_json: bool) -> None:  # noqa: ARG001
 @click.option("--all", help="List all clusters, including inactive ones.", is_flag=True)
 @click.option("--json", "show_json", help="Return the results in json", is_flag=True)
 def session_list(name: Optional[str], all: bool, show_json: bool) -> None:  # noqa: A002
-    log.warning(
-        "`anyscale list sessions` has been deprecated. Please use `anyscale cluster list` instead."
-    )
+    """List all clusters within the current project.
+
+    DEPRECATED: This command will be removed on 2025-10-01.
+    Use 'anyscale cluster list' instead.
+    """
     list_controller = ListController()
     output = list_controller.list_sessions(
         name=name, show_all=all, json_format=show_json
@@ -79,7 +100,16 @@ def session_list(name: Optional[str], all: bool, show_json: bool) -> None:  # no
     name="ips",
     help="[DEPRECATED] List IP addresses of head and worker nodes.",
     context_settings={"ignore_unknown_options": True, "allow_extra_args": True,},
+    cls=DeprecatedAnyscaleCommand,
+    removal_date="2025-10-01",
+    deprecation_message="Listing IPs is not supported on Anyscale",
+    alternative="use the Anyscale console to view cluster node information",
 )
 def list_ips() -> None:
-    """List IP addresses of head and worker nodes."""
-    raise click.ClickException("Listing IPs is not supported on Anyscale V2")
+    """List IP addresses of head and worker nodes.
+
+    DEPRECATED: This command will be removed on 2025-10-01.
+    Listing IPs is not supported on Anyscale.
+    Use the Anyscale console to view cluster node information.
+    """
+    raise click.ClickException("Listing IPs is not supported on Anyscale")
