@@ -4,9 +4,11 @@ This file holds all of the CLI commands for the "anyscale machine" path.
 from typing import Optional
 
 import click
+import humanize
 from rich import print_json
 import tabulate
 
+from anyscale.commands.util import LegacyAnyscaleCommand
 from anyscale.controllers.machine_controller import MachineController
 
 
@@ -17,9 +19,13 @@ def machine_cli() -> None:
     pass
 
 
-@machine_cli.command(name="list", help="List machines registered to Anyscale.")
-@click.option("--cloud", type=str, help="Provide a cloud name.")
-@click.option("--cloud-id", type=str, help="Provide a cloud ID.")
+@machine_cli.command(
+    name="list",
+    help="List machines registered to Anyscale.",
+    cls=LegacyAnyscaleCommand,
+    is_limited_support=True,
+    legacy_prefix="anyscale machine",
+)
 @click.option("--machine-pool-name", type=str, help="Provide a machine pool name.")
 @click.option(
     "--format",
@@ -28,22 +34,9 @@ def machine_cli() -> None:
     default="table",
     help="The format to return results in.",
 )
-def list_machines(
-    cloud: Optional[str],
-    cloud_id: Optional[str],
-    machine_pool_name: Optional[str],
-    format_: str,
-) -> None:
-
-    if not cloud and not cloud_id and not machine_pool_name:
-        raise ValueError(
-            "One of {'cloud', 'cloud-id', 'machine-pool-name'} must be provided."
-        )
-
+def list_machines(machine_pool_name: str, format_: str,) -> None:
     machines_controller = MachineController()
-    output = machines_controller.list_machines(
-        cloud=cloud, cloud_id=cloud_id, machine_pool_name=machine_pool_name
-    )
+    output = machines_controller.list_machines(machine_pool_name)
 
     if format_ == "json":
         rows = []
@@ -53,6 +46,9 @@ def list_machines(
                     "machine_id": m.machine_id,
                     "hostname": m.hostname,
                     "machine_shape": m.machine_shape,
+                    "num_cpus": m.num_cpus,
+                    "num_gpus": m.num_gpus,
+                    "memory": humanize.naturalsize(m.memory_bytes, binary=True),
                     "connection_state": m.connection_state,
                     "allocation_state": m.allocation_state,
                     "cluster_id": m.cluster_id,
@@ -68,6 +64,9 @@ def list_machines(
             "MACHINE",
             "HOSTNAME",
             "SHAPE",
+            "NUM_CPUS",
+            "NUM_GPUS",
+            "MEMORY",
             "HEALTHY",
             "STATUS",
             "OWNER",
@@ -81,6 +80,9 @@ def list_machines(
                     m.machine_id,
                     m.hostname,
                     m.machine_shape,
+                    m.num_cpus,
+                    m.num_gpus,
+                    humanize.naturalsize(m.memory_bytes, binary=True),
                     "Yes" if m.connection_state == "connected" else "No",
                     m.allocation_state.title(),
                     m.cluster_creator_name,
@@ -95,20 +97,20 @@ def list_machines(
         )
 
 
-@machine_cli.command(name="delete", help="Delete a machine from a machine pool.")
-@click.option("--cloud", type=str, help="Provide a cloud name.")
-@click.option("--cloud-id", type=str, help="Provide a cloud ID.")
+@machine_cli.command(
+    name="delete",
+    help="Delete a machine from a machine pool.",
+    cls=LegacyAnyscaleCommand,
+    is_limited_support=True,
+    legacy_prefix="anyscale machine",
+)
 @click.option("--machine-id", type=str, help="Provide a machine ID.")
-def delete_machine(
-    cloud: Optional[str], cloud_id: Optional[str], machine_id: str
-) -> None:
-
-    if not cloud and not cloud_id:
-        raise ValueError("One of {'cloud', 'cloud-id'} must be provided.")
+@click.option("--machine-pool-name", type=str, help="Provide a machine pool name.")
+def delete_machine(machine_id: str, machine_pool_name: Optional[str],) -> None:
 
     machines_controller = MachineController()
     machines_controller.delete_machine(
-        cloud=cloud, cloud_id=cloud_id, machine_id=machine_id,
+        machine_id=machine_id, machine_pool_name=machine_pool_name,
     )
 
     print(f"Machine {machine_id} has been deleted.")
