@@ -102,6 +102,10 @@ def describe(name: str, format_: str) -> None:
     if format_ == "json":
         print(json.dumps(scheduler_info.to_dict(), default=str))
     elif format_ == "table":
+
+        def format_time(timestamp):
+            return str(timestamp.astimezone().strftime("%m/%d/%Y %I:%M:%S %p %Z"))
+
         machines_table = []
         columns = [
             "MACHINE ID",
@@ -109,8 +113,9 @@ def describe(name: str, format_: str) -> None:
             "PARTITION",
             "STATE",
             "WORKLOAD DETAILS",
-            "WORKLOAD SCORE",
             "WORKLOAD START TIME",
+            "WORKLOAD CREATOR",
+            "WORKLOAD SCORE",
             "CLOUD INSTANCE ID",
         ]
         for row in scheduler_info.machines:
@@ -120,17 +125,16 @@ def describe(name: str, format_: str) -> None:
                     row.machine_type,
                     row.partition,
                     row.allocation_state,
-                    f"{row.workload_info.workload_type}/{row.workload_info.workload_name}/{row.workload_info.workload_cloud}"
+                    f"{row.workload_info.workload_type}/{row.workload_info.workload_name}/{row.workload_info.workload_project}/{row.workload_info.workload_cloud}"
+                    if row.workload_info.workload_name
+                    else "",
+                    format_time(row.workload_info.workload_start_time)
+                    if row.workload_info.workload_name
+                    else "",
+                    row.workload_info.workload_creator
                     if row.workload_info.workload_name
                     else "",
                     row.workload_score,
-                    str(
-                        row.workload_info.workload_start_time.astimezone().strftime(
-                            "%m/%d/%Y %I:%M:%S %p %Z"
-                        )
-                    )
-                    if row.workload_info.workload_name
-                    else "",
                     row.cloud_instance_id,
                 ]
             )
@@ -151,7 +155,7 @@ def describe(name: str, format_: str) -> None:
             "MACHINE TYPE",
             "WORKLOAD DETAILS",
             "WORKLOAD START TIME",
-            "WORKLOAD CLOUD",
+            "WORKLOAD CREATOR",
             "PARTITION SCORES",
         ]
         for row in scheduler_info.requests:
@@ -159,15 +163,9 @@ def describe(name: str, format_: str) -> None:
                 [
                     row.size,
                     row.machine_type,
-                    f"{row.workload_info.workload_type}/{row.workload_info.workload_name}",
-                    str(
-                        row.workload_info.workload_start_time.astimezone().strftime(
-                            "%m/%d/%Y %I:%M:%S %p %Z"
-                        )
-                    )
-                    if row.workload_info.workload_name
-                    else "",
-                    row.workload_info.workload_cloud,
+                    f"{row.workload_info.workload_type}/{row.workload_info.workload_name}/{row.workload_info.workload_project}/{row.workload_info.workload_cloud}",
+                    format_time(row.workload_info.workload_start_time),
+                    row.workload_info.workload_creator,
                     row.partition_scores,
                 ]
             )
@@ -180,6 +178,15 @@ def describe(name: str, format_: str) -> None:
             )
         )
 
+        if (
+            scheduler_info.recent_launch_failures
+            and len(scheduler_info.recent_launch_failures) > 0
+        ):
+            print("Recent Launch Failures:")
+            for failure in scheduler_info.recent_launch_failures:
+                error = failure.error.replace("\n", " ")
+                print(f"- [{format_time(failure.timestamp)}] {error}")
+
 
 @machine_pool_cli.command(
     name="delete",
@@ -253,7 +260,13 @@ def list_machine_pools(format_: str) -> None:
         raise click.ClickException(f"Invalid output format '{format}'.")
 
 
-@machine_pool_cli.command(name="attach", help="Attach a machine pool to a cloud.")
+@machine_pool_cli.command(
+    name="attach",
+    help="Attach a machine pool to a cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.MACHINE_POOL_ATTACH_EXAMPLE,
+    is_beta=True,
+)
 @click.option("--name", type=str, required=True, help="Provide a machine pool name.")
 @click.option("--cloud", type=str, required=True, help="Provide a cloud name.")
 def attach_machine_pool_to_cloud(name: str, cloud: str) -> None:
@@ -264,7 +277,13 @@ def attach_machine_pool_to_cloud(name: str, cloud: str) -> None:
     print(f"Attached machine pool '{name}' to cloud '{cloud}'.")
 
 
-@machine_pool_cli.command(name="detach", help="Detach a machine pool from a cloud.")
+@machine_pool_cli.command(
+    name="detach",
+    help="Detach a machine pool from a cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.MACHINE_POOL_DETACH_EXAMPLE,
+    is_beta=True,
+)
 @click.option("--name", type=str, required=True, help="Provide a machine pool name.")
 @click.option("--cloud", type=str, required=True, help="Provide a cloud name.")
 def detach_machine_pool_from_cloud(name: str, cloud: str) -> None:
