@@ -315,7 +315,7 @@ worker_nodes:
 
 @dataclass(frozen=True)
 class ComputeConfig(ModelBase):
-    """Configuration for instance types and cloud resources for a cluster."""
+    """Compute configuration for instance types and cloud resources for a cluster with a single cloud resource."""
 
     __doc_py_example__ = """
 from anyscale.compute_config.models import (
@@ -417,6 +417,19 @@ advanced_instance_config: # (Optional) Defaults to no advanced configurations.
         if cloud is not None and not isinstance(cloud, str):
             raise TypeError("'cloud' must be a string")
 
+    cloud_resource: Optional[str] = field(
+        default=None,
+        repr=False,
+        metadata={
+            "docstring": "The cloud resource to use for this workload. Defaults to the primary cloud resource of the Cloud.",
+            "customer_hosted_only": True,
+        },
+    )
+
+    def _validate_cloud_resource(self, cloud_resource: Optional[str]):
+        if cloud_resource is not None and not isinstance(cloud_resource, str):
+            raise TypeError("'cloud_resource' must be a string")
+
     head_node: Union[HeadNodeConfig, Dict, None] = field(
         default=None,
         repr=False,
@@ -569,6 +582,183 @@ advanced_instance_config: # (Optional) Defaults to no advanced configurations.
         if not isinstance(flags, dict):
             raise TypeError("'flags' must be a dict")
 
+    auto_select_worker_config: bool = field(
+        default=False,
+        repr=False,
+        metadata={
+            "docstring": "Allow worker groups to be automatically configured based on the workload's logical resource requests. When false, worker groups must be explicitly configured.",
+        },
+    )
+
+    def _validate_auto_select_worker_config(self, auto_select_worker_config: bool):
+        if not isinstance(auto_select_worker_config, bool):
+            raise TypeError("'auto_select_worker_config' must be a boolean")
+        if auto_select_worker_config and self.worker_nodes is not None:
+            raise ValueError(
+                "'auto_select_worker_config' must be false when 'worker_nodes' are provided"
+            )
+
+
+@dataclass(frozen=True)
+class MultiResourceComputeConfig(ModelBase):
+    """EXPERIMENTAL. Compute configuration for a cluster with multiple possible cloud resources."""
+
+    __doc_py_example__ = """
+from anyscale.compute_config.models import (
+    MultiResourceComputeConfig, ComputeConfig, HeadNodeConfig, WorkerNodeGroupConfig
+)
+config = MultiResourceComputeConfig(
+    cloud="my-cloud",
+    configs=[
+        ComputeConfig(
+            cloud_resource="vm-aws-us-west-1",
+            head_node=HeadNodeConfig(
+                instance_type="m5.2xlarge",
+            ),
+            worker_nodes=[
+                WorkerNodeGroupConfig(
+                    instance_type="m5.4xlarge",
+                    min_nodes=1,
+                    max_nodes=10,
+                ),
+            ],
+        ),
+        ComputeConfig(
+            cloud_resource="vm-aws-us-west-2",
+            head_node=HeadNodeConfig(
+                instance_type="m5.2xlarge",
+            ),
+            worker_nodes=[
+                WorkerNodeGroupConfig(
+                    instance_type="m5.4xlarge",
+                    min_nodes=1,
+                    max_nodes=10,
+                ),
+            ],
+        )
+    ]
+)
+"""
+
+    __doc_yaml_example__ = """
+cloud: my-cloud
+configs:
+- cloud_resource: vm-aws-us-west-1
+  head_node:
+    instance_type: m5.2xlarge
+  worker_nodes:
+  - instance_type: m5.4xlarge
+    min_nodes: 1
+    max_nodes: 10
+- cloud_resource: vm-aws-us-west-2
+  head_node:
+    instance_type: m5.2xlarge
+  worker_nodes:
+  - instance_type: m5.4xlarge
+    min_nodes: 1
+    max_nodes: 10
+"""
+    cloud: Optional[str] = field(
+        default=None,
+        metadata={
+            "docstring": "The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace)."
+        },
+    )
+
+    def _validate_cloud(self, cloud: Optional[str]):
+        if cloud is not None and not isinstance(cloud, str):
+            raise TypeError("'cloud' must be a string")
+
+    configs: List[Union[ComputeConfig, Dict]] = field(
+        default_factory=list,
+        repr=False,
+        metadata={
+            "docstring": "List of compute configurations, one for each cloud resource.",
+            "customer_hosted_only": True,
+        },
+    )
+
+    def _validate_configs(
+        self, configs: List[Union[ComputeConfig, Dict]]
+    ) -> List[ComputeConfig]:
+        if not isinstance(configs, list) or not all(
+            isinstance(c, (dict, ComputeConfig)) for c in configs
+        ):
+            raise TypeError(
+                "'configs' must be a list of ComputeConfigs or corresponding dicts"
+            )
+
+        config_models: List[ComputeConfig] = []
+        unique_clouds = set()
+        unique_resources = set()
+        for config in configs:
+            if isinstance(config, dict):
+                config = ComputeConfig.from_dict(config)
+
+            assert isinstance(config, ComputeConfig)
+            config_models.append(config)
+
+            if config.cloud:
+                unique_clouds.add(config.cloud)
+
+            unique_resources.add(config.cloud_resource)
+
+        if len(unique_clouds) > 1:
+            raise ValueError("'cloud' must be the same for all configs.")
+
+        if len(unique_resources) != len(configs):
+            raise ValueError(
+                "'cloud_resource' must be unique for each compute configuration."
+            )
+
+        if len(configs) == 0:
+            raise ValueError(
+                "'configs' must include at least one compute configuration."
+            )
+
+        return config_models
+
+
+ComputeConfigType = Union[ComputeConfig, MultiResourceComputeConfig]
+
+
+def compute_config_type_from_yaml(config_file: str) -> ComputeConfigType:
+    """
+    Parse a YAML compute config file into either a ComputeConfig or MultiResourceComputeConfig.
+    """
+    error_message = f"Could not parse config file '{config_file}' as a ComputeConfig or MultiResourceComputeConfig:\n"
+
+    try:
+        return ComputeConfig.from_yaml(config_file)
+    except Exception as e:  # noqa: BLE001
+        error_message += f"ComputeConfig: {e}\n"
+
+    try:
+        return MultiResourceComputeConfig.from_yaml(config_file)
+    except Exception as e:  # noqa: BLE001
+        error_message += f"MultiResourceComputeConfig: {e}\n"
+
+    raise TypeError(error_message.rstrip())
+
+
+def compute_config_type_from_dict(config_dict: Dict) -> ComputeConfigType:
+    """
+    Parse a compute config dict into either a ComputeConfig or MultiResourceComputeConfig.
+    """
+    error_message = f"Could not parse config dict '{config_dict}' as a ComputeConfig or MultiResourceComputeConfig:\n"
+
+    try:
+        return ComputeConfig.from_dict(config_dict)
+    except Exception as e:  # noqa: BLE001
+        error_message += f"ComputeConfig: {e}\n"
+
+    try:
+        return MultiResourceComputeConfig.from_dict(config_dict)
+    except Exception as e:  # noqa: BLE001
+        error_message += f"MultiResourceComputeConfig: {e}\n"
+
+    raise TypeError(error_message.rstrip())
+
 
 @dataclass(frozen=True)
 class ComputeConfigVersion(ModelBase):
@@ -623,8 +813,14 @@ config:
         if not isinstance(id, str):
             raise TypeError("'id' must be a string.")
 
-    config: ComputeConfig = field(metadata={"docstring": "The compute configuration."},)
+    config: Optional[ComputeConfigType] = field(
+        default=None, metadata={"docstring": "The compute configuration."},
+    )
 
-    def _validate_config(self, config: ComputeConfig):
-        if not isinstance(config, ComputeConfig):
-            raise TypeError("'config' must be a ComputeConfig")
+    def _validate_config(self, config: Optional[ComputeConfigType]):
+        if config is not None and not isinstance(
+            config, (ComputeConfig, MultiResourceComputeConfig)
+        ):
+            raise TypeError(
+                "'config' must be a ComputeConfig or MultiResourceComputeConfig"
+            )
