@@ -48,7 +48,7 @@ from anyscale.connect_utils.start_interactive_session import (  # pylint:disable
     _get_interactive_shell_frame,
     start_interactive_session_block,
 )
-import anyscale.project
+import anyscale.project_utils
 from anyscale.sdk.anyscale_client.sdk import AnyscaleSDK
 from anyscale.shared_anyscale_utils.util import slugify
 from anyscale.util import PROJECT_NAME_ENV_VAR
