@@ -7,13 +7,14 @@ import yaml
 import anyscale
 from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
-from anyscale.cloud import (
+from anyscale.cloud_utils import (
     get_cloud_id_and_name,
     get_last_used_cloud,
     get_organization_default_cloud,
 )
 from anyscale.cluster_compute import get_cluster_compute_from_name
 import anyscale.conf
+import anyscale.project_utils
 from anyscale.sdk.anyscale_client import ComputeTemplateConfig
 from anyscale.utils.connect_helpers import find_project_id
 
@@ -70,7 +71,7 @@ class ProjectBlock:
         self.log.open_block(self.block_label, block_title="Choosing a project")
 
         if self.project_dir is None and project_name is None:
-            self.project_dir = anyscale.project.find_project_root(os.getcwd())
+            self.project_dir = anyscale.project_utils.find_project_root(os.getcwd())
 
         parent_cloud_id = self._get_parent_cloud_id(
             self.cloud_name, self.cluster_compute_name, self.cluster_compute_dict,
@@ -186,8 +187,10 @@ class ProjectBlock:
         project_yaml = os.path.join(project_dir, ".anyscale.yaml")
         if os.path.exists(project_yaml):
             # Validate format of project yaml and get project id
-            proj_def = anyscale.project.ProjectDefinition(project_dir)
-            project_id: Optional[str] = anyscale.project.get_project_id(proj_def.root)
+            proj_def = anyscale.project_utils.ProjectDefinition(project_dir)
+            project_id: Optional[str] = anyscale.project_utils.get_project_id(
+                proj_def.root
+            )
             if not project_id:
                 raise click.ClickException(
                     f"{project_yaml} is not correctly formatted. Please attach to a different "
