@@ -329,7 +329,10 @@ class StartInteractiveSessionBlock:
     ) -> Tuple[str, bool, Any]:
         """Get the params from the cluster needed to use Ray client."""
         connect_url = None
-        metadata = [("cookie", "anyscale-token=" + session_meta.access_token)]
+        access_token = self.api_client.get_cluster_access_token_api_v2_authentication_cluster_id_cluster_access_token_get(
+            cluster_id=session_meta.id
+        )
+        metadata = [("cookie", "anyscale-token=" + access_token)]
         if session_meta.connect_url:
             url_components = session_meta.connect_url.split("?port=")
             metadata += [("port", url_components[1])] if len(url_components) > 1 else []
