@@ -264,7 +264,7 @@ class ConfigController(BaseController):
             allowed_azs=allowed_azs,
             head_node_type=head_node,
             worker_node_types=worker_nodes,
-            aws=global_aws_options,
+            aws_advanced_configurations_json=global_aws_options,
         )
 
     def _convert_cluster_env(
