@@ -9,10 +9,10 @@ from typing import Any, Dict, List, Optional, Tuple
 import tabulate
 
 from anyscale.cli_logger import BlockLogger
-from anyscale.cloud import get_cloud_json_from_id
+from anyscale.cloud_utils import get_cloud_json_from_id
 from anyscale.controllers.base_controller import BaseController
 from anyscale.formatters import clouds_formatter
-from anyscale.project import (
+from anyscale.project_utils import (
     get_project_id,
     load_project_or_throw,
 )
