@@ -12,6 +12,7 @@ import click
 from rich.console import Console
 from rich.progress import track
 
+from anyscale.api_utils.job_util import _get_job_run_id
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models import (
     LogDownloadConfig,
@@ -59,6 +60,13 @@ class LogsController(BaseController):
         # spam the CLI output when users have had multiple sessions.
         self._unpack_log_sent = False
 
+    def get_cluster_id_for_last_prodjob_run(self, prodjob_id: str):
+        last_job_run_id = _get_job_run_id(self.anyscale_api_client, job_id=prodjob_id)
+        last_job_run = self.api_client.get_decorated_job_api_v2_decorated_jobs_job_id_get(
+            job_id=last_job_run_id
+        )
+        return last_job_run.result.cluster_id
+
     def render_logs(
         self, log_group: LogGroup, parallelism: int, read_timeout: timedelta, tail: int
     ):
