@@ -66,12 +66,7 @@ class ProjectController(BaseController):
         """
         Call API to create a new project given a project name.
         """
-        if not parent_cloud_id and (
-            self.api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-                "cloud-isolation-phase-1"
-            ).result.is_on
-            is True
-        ):
+        if not parent_cloud_id:
             raise click.ClickException(
                 "Parent cloud id should be specified when creating a new project because "
                 "cloud isolation has been enabled."
