@@ -16,7 +16,11 @@ from anyscale.client.openapi_client.models.production_job import ProductionJob
 from anyscale.client.openapi_client.models.ray_runtime_env_config import (
     RayRuntimeEnvConfig,
 )
-from anyscale.compute_config.models import ComputeConfig
+from anyscale.compute_config.models import (
+    ComputeConfig,
+    ComputeConfigType,
+    MultiResourceComputeConfig,
+)
 from anyscale.job.models import (
     JobConfig,
     JobLogMode,
@@ -63,7 +67,7 @@ class PrivateJobSDK(WorkloadSDK):
         config: JobConfig,
         *,
         autopopulate_in_workspace: bool = True,
-        cloud_id: Optional[str] = None,
+        cloud_id: str,
         workspace_requirements_path: Optional[str] = None,
     ) -> Optional[Dict[str, Any]]:
         """Populates a runtime_env from the config.
@@ -78,16 +82,34 @@ class PrivateJobSDK(WorkloadSDK):
             - 'working_dir' will be set to '.'.
             - 'pip' will be set to the workspace-managed requirements file.
         """
-        runtime_env: Dict[str, Any] = {}
-        [runtime_env] = self.override_and_upload_local_dirs(
-            [runtime_env],
-            working_dir_override=config.working_dir,
-            excludes_override=config.excludes,
-            cloud_id=cloud_id,
-            autopopulate_in_workspace=autopopulate_in_workspace,
-            additional_py_modules=config.py_modules,
-            py_executable_override=config.py_executable,
+        cloud_resource_names = self._get_compute_config_cloud_resources(
+            compute_config=config.compute_config, cloud=config.cloud
         )
+        assert len(cloud_resource_names) > 0
+
+        runtime_env: Dict[str, Any] = {}
+        if len(cloud_resource_names) == 1:
+            [runtime_env] = self.override_and_upload_local_dirs_single_deployment(
+                [runtime_env],
+                working_dir_override=config.working_dir,
+                excludes_override=config.excludes,
+                cloud_id=cloud_id,
+                autopopulate_in_workspace=autopopulate_in_workspace,
+                additional_py_modules=config.py_modules,
+                py_executable_override=config.py_executable,
+                cloud_resource_name=cloud_resource_names[0],
+            )
+        else:
+            [runtime_env] = self.override_and_upload_local_dirs_multi_cloud_resource(
+                [runtime_env],
+                working_dir_override=config.working_dir,
+                excludes_override=config.excludes,
+                cloud_id=cloud_id,
+                autopopulate_in_workspace=autopopulate_in_workspace,
+                additional_py_modules=config.py_modules,
+                py_executable_override=config.py_executable,
+                cloud_resource_names=cloud_resource_names,
+            )
         [runtime_env] = self.override_and_load_requirements_files(
             [runtime_env],
             requirements_override=config.requirements,
@@ -99,6 +121,33 @@ class PrivateJobSDK(WorkloadSDK):
 
         return runtime_env or None
 
+    def _get_compute_config_cloud_resources(
+        self, compute_config: Union[ComputeConfigType, str, None], cloud: Optional[str]
+    ) -> List[Optional[str]]:
+        if isinstance(compute_config, ComputeConfig):
+            # single-cloud resource compute config
+            return [compute_config.cloud_resource]
+
+        if isinstance(compute_config, MultiResourceComputeConfig):
+            return [config.cloud_resource for config in compute_config.configs]
+
+        compute_config_id = self._resolve_compute_config_id(
+            compute_config=compute_config, cloud=cloud
+        )
+        compute_template = self._client.get_compute_config(compute_config_id)
+        if compute_template is None or compute_template.config is None:
+            raise ValueError(
+                f"The compute config '{compute_config_id}' does not exist."
+            )
+
+        if compute_template.config.deployment_configs is None:
+            return [None]
+
+        return [
+            config.cloud_deployment
+            for config in compute_template.config.deployment_configs
+        ]
+
     def get_default_name(self) -> str:
         """Get a default name for the job.
 
