@@ -23,7 +23,7 @@ from anyscale.cluster_env import (
     get_default_cluster_env_build,
     validate_successful_build,
 )
-from anyscale.project import (
+from anyscale.project_utils import (
     get_parent_cloud_id_and_name_of_project,
     get_proj_id_from_name,
 )
