@@ -14,6 +14,7 @@ from anyscale.cluster_compute import (
     get_cluster_compute_from_name,
     get_selected_cloud_id_or_default,
 )
+from anyscale.sdk.anyscale_client.api.default_api import DefaultApi as SDKDefaultApi
 from anyscale.sdk.anyscale_client.models.cluster_compute_config import (
     ClusterComputeConfig,
 )
@@ -277,10 +278,7 @@ def get_parent_cloud_id_and_name_of_project(
     project = api_client.get_project_api_v2_projects_project_id_get(
         project_id=project_id
     ).result
-    cloud_isolation_ff_on = api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-        "cloud-isolation-phase-1"
-    ).result.is_on
-    if project and cloud_isolation_ff_on:
+    if project:
         parent_cloud_id, parent_cloud_name = get_cloud_id_and_name(
             api_client, cloud_id=project.parent_cloud_id
         )
@@ -398,7 +396,7 @@ def get_and_validate_project_id(
     project_name: Optional[str],
     parent_cloud_id: Optional[str],
     api_client: DefaultApi,
-    anyscale_api_client: DefaultApi,
+    anyscale_api_client: Union[DefaultApi, SDKDefaultApi],
 ) -> str:
     project_name = project_name or os.environ.get(PROJECT_NAME_ENV_VAR)
     if project_id:
@@ -424,7 +422,7 @@ def get_and_validate_project_id(
 
 def get_default_project(
     api_client: Optional[DefaultApi] = None,
-    anyscale_api_client: Optional[DefaultApi] = None,
+    anyscale_api_client: Optional[Union[DefaultApi, SDKDefaultApi]] = None,
     parent_cloud_id: Optional[str] = None,
 ):
     """
@@ -439,27 +437,19 @@ def get_default_project(
         anyscale_api_client or get_auth_api_client(log_output=False).anyscale_api_client
     )
     api_client = api_client or get_auth_api_client(log_output=False).api_client
-    if (
-        api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-            "cloud-isolation-phase-1"
-        ).result.is_on
-        is False
-    ):
-        default_project = anyscale_api_client.get_default_project().result
-    else:
-        if not parent_cloud_id:
-            raise click.ClickException(
-                "Please specify a cloud for this command either through the cloud or "
-                "compute config arguments."
-            )
-        default_project = anyscale_api_client.get_default_project(
-            parent_cloud_id=parent_cloud_id
-        ).result
+    if not parent_cloud_id:
+        raise click.ClickException(
+            "Please specify a cloud for this command either through the cloud or "
+            "compute config arguments."
+        )
+    default_project = anyscale_api_client.get_default_project(  # type: ignore
+        parent_cloud_id=parent_cloud_id
+    ).result
     return default_project
 
 
 def infer_project_id(  # noqa PLR0913
-    anyscale_api_client: DefaultApi,
+    anyscale_api_client: Union[DefaultApi, SDKDefaultApi],
     api_client: DefaultApi,
     log: BlockLogger,
     project_id: Optional[str],
