@@ -3,7 +3,7 @@ import os
 from click import ClickException
 import yaml
 
-from anyscale.project import ANYSCALE_PROJECT_FILE, find_project_root
+from anyscale.project_utils import ANYSCALE_PROJECT_FILE, find_project_root
 
 
 def write_workspace_id_to_disk(workspace_id: str, directory: str) -> None:
